<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<xsl:stylesheet xmlns="urn:gba:sqg" xmlns:iqtig="http://www.iqtig.org" xmlns:saxon="http://saxon.sf.net" xmlns:xalan="http://xml.apache.org/xalan" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" exclude-result-prefixes="xs xsi iqtig saxon xalan #default" version="2.0" xpath-default-namespace="urn:gba:sqg">
	<xsl:variable name="OPS">
		<OPS_LISTEN/>
	</xsl:variable>
	<xsl:variable name="ICD">
		<ICD_LISTEN/>
	</xsl:variable>
	<xsl:variable name="EBM">
		<EBM_LISTEN/>
	</xsl:variable>
	<xsl:variable name="tool_version" select="'IQTIG Datenpruefprogramm 2024_QSFFx_DPP_V05'"/>
	<xsl:param name="validation_id"/>
	<xsl:param name="c_date"/>
	<xsl:param name="provider_address"/>
	<xsl:param name="provider_email"/>
	<xsl:param name="provider_fax"/>
	<xsl:param name="provider_function"/>
	<xsl:param name="provider_name"/>
	<xsl:param name="provider_phone"/>
	<xsl:param name="provider_registration"/>
	<xsl:output encoding="UTF-8" indent="yes" method="xml"/>
	<!-- pre checks-->
	<!-- prüfung 30 -->
	<xsl:variable name="pruefung_30_ist_verletzt" select="/root/header/protocol/status_document/@V = 'ERROR'"/>
	<!-- prüfung 173 -->
	<xsl:variable name="pruefung_173_ist_verletzt" select="count(distinct-values(//C/felder/STICHTAG/@V union //C/felder/STICHTAGAE/@V)) != count(//C/felder/STICHTAG/@V union //C/felder/STICHTAGAE/@V)"/>
	<!-- prüfung 174 -->
	<!-- iqtig:exists und iqtig:is_date nicht notwendig, da nur harte schemata in qsffx -->
	<!-- wenn " "-LeerString, dann Schemaverletzung wegen date-regex -->
	<!--/root/body/data_container/cases/case/qs_data/@module = ('F_NW', 'F_SA', 'F_SA23') nicht notwendig, da xsl nur prüft,wenn Elemente existieren -->
	<xsl:variable name="pruefung_174_ist_verletzt" select="//C[	 .//STICHTAG[  ./@V and ./ancestor::C/following-sibling::C[1]//STICHTAG/@V and iqtig:compare(./@V, ./ancestor::C/following-sibling::C[1]//STICHTAG/@V, '&gt;')]  or  .//STICHTAG[  ./@V and ./ancestor::C/following-sibling::C[1]//STICHTAGAE/@V and iqtig:compare(./@V, ./ancestor::C/following-sibling::C[1]//STICHTAGAE/@V, '&gt;')]  or  .//STICHTAGAE[./@V and ./ancestor::C/following-sibling::C[1]//STICHTAG/@V and iqtig:compare(./@V, ./ancestor::C/following-sibling::C[1]//STICHTAG/@V, '&gt;')] or  .//STICHTAGAE[./@V and ./ancestor::C/following-sibling::C[1]//STICHTAGAE/@V and iqtig:compare(./@V, ./ancestor::C/following-sibling::C[1]//STICHTAGAE/@V, '&gt;')] ]//LFDCHL/@V"/>
	<!-- Formatfehler über die eigentliche Schemaprüfung -->
	<!-- QSFFx hat keine weichen Schemata -->
	<xsl:variable name="pruefung_179_ist_verletzt" select="/root/header/document/data_flow/@V = 'LE_BAS' and not(iqtig:exists(/root/header/dfp_key/@V))"/>
	<xsl:variable name="prechecks_ok" select="not($pruefung_30_ist_verletzt or $pruefung_173_ist_verletzt or $pruefung_174_ist_verletzt or $pruefung_179_ist_verletzt)"/>
	<xsl:variable name="protocol">
		<xsl:apply-templates select="/root/body/data_container/cases/case"/>
	</xsl:variable>
	<xsl:variable name="protocol_header">
		<xsl:if test="$pruefung_30_ist_verletzt">
			<error>
				<rule_id V="1001014"/>
				<rule_type V="H"/>
				<error_message V="Das Dokument ist bereits als fehlerhaft (ERROR) markiert."/>
			</error>
		</xsl:if>
		<xsl:if test="$pruefung_173_ist_verletzt">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001053"/>
				<rule_type V="H"/>
				<error_message V="{concat('Die BogenFelder &quot;Stichtag&quot; und &quot;Datum des Eintretens der Nichterfüllung bzw. der Wiedererfüllung&quot; müssen in jedem Bogen/Teildatensatz &quot;Checkliste&quot; unterschiedliche Datumsangaben enthalten. Es gibt aber doppelte Datumsangaben in den Checklisten mit den laufenden Nummern: ',string-join(//C[ .//STICHTAG[./@V = ./ancestor::C/following-sibling::*//STICHTAG/@V] or .//STICHTAG[./@V = ./ancestor::C/preceding-sibling::*//STICHTAG/@V] or .//STICHTAG[./@V = ./ancestor::C/following-sibling::*//STICHTAGAE/@V] or .//STICHTAG[./@V = ./ancestor::C/preceding-sibling::*//STICHTAGAE/@V] or .//STICHTAGAE[./@V = ./ancestor::C/following-sibling::*//STICHTAG/@V] or .//STICHTAGAE[./@V = ./ancestor::C/preceding-sibling::*//STICHTAG/@V] or .//STICHTAGAE[./@V = ./ancestor::C/following-sibling::*//STICHTAGAE/@V] or .//STICHTAGAE[./@V = ./ancestor::C/preceding-sibling::*//STICHTAGAE/@V] ]//LFDCHL/@V,&quot;, &quot;))}"/>
			</error>
		</xsl:if>
		<xsl:if test="$pruefung_174_ist_verletzt">
			<error>
			<error_type V="EXPORT"/>
				<rule_id V="1001054"/>
				<rule_type V="H"/>
				<error_message V="{concat(&quot;In der Exportdatei müssen die Checklisten zeitlich aufsteigend sortiert sein (BogenFelder Stichtag bzw. Datum des Eintretens der Nichterfüllung bzw. der Wiedererfüllung). Die Checklisten mit den laufenden Nummern sind aber jünger als ihre Nachfolger: &quot;,string-join($pruefung_174_ist_verletzt,&quot;, &quot;))}"/>
			</error>
		</xsl:if>
		<xsl:if test="$pruefung_179_ist_verletzt">
			<error>
				<rule_id V="1001059"/>
				<rule_type V="H"/>
				<error_message V="In der Exportdatei fehlt das XML-Attribut dfp_key/@V. Die an die BAS übermittelte Exportdatei muss aber für die verschlüsselte Rückübermittlung des vollständigen Datenflussprotokolls zwingend das Attribut dfp_key/@V enthalten."/>
			</error>
		</xsl:if>
		<xsl:if test="$prechecks_ok">
			<xsl:apply-templates mode="check_date" select="/root/header/document/origination_dttm"/>
			<xsl:apply-templates mode="check_date" select="/root/header/document/modification_dttm"/>
			<xsl:apply-templates mode="check_cases" select="/root/body/data_container/cases"/>
		</xsl:if>
	</xsl:variable>
	<xsl:template match="/">
		<xsl:apply-templates mode="copy"/>
	</xsl:template>
	<xsl:template match="protocol[exists(parent::case_admin)]" mode="copy">
		<xsl:variable name="case_id" select="generate-id(parent::case_admin/parent::case)"/>
		<xsl:variable name="errors" select="$protocol/case[@id = $case_id]"/>
		<xsl:variable name="status" select="iqtig:get_status($errors, false())"/>
		<protocol>
			<xsl:apply-templates mode="copy" select="node() | @*"/>
			<xsl:if test="$status != 'OK'">
				<validation_item V="Spezifikation" c_date="{$c_date}" id="{$validation_id}">
					<status V="{$status}">
						<xsl:for-each select="$errors//error">
							<xsl:variable name="this" select="."/>
							<xsl:copy-of select="$this"/>
						</xsl:for-each>
					</status>
				</validation_item>
			</xsl:if>
		</protocol>
	</xsl:template>
	<xsl:template match="protocol[exists(parent::header)]" mode="copy">
		<protocol>
			<xsl:if test="not(.//validation_provider[@registration=$provider_registration])">
				<validation_provider address="{$provider_address}" email="{$provider_email}" fax="{$provider_fax}" function="{$provider_function}" name="{$provider_name}" phone="{$provider_phone}" registration="{$provider_registration}">
					<validation_item V="Spezifikation" c_date="{$c_date}" check_tool="{$tool_version}" id="{$validation_id}">
						<xsl:choose>
					<xsl:when test="$protocol_header/error[./rule_type/@V='H']">
						<status V="{iqtig:get_status_document($protocol/case, 'ERROR', 'ERROR')}">
							<xsl:copy-of select="$protocol_header/error"/>
						</status>
					</xsl:when>
					<xsl:when test="$protocol_header/error[./rule_type/@V='W']">
						<status V="{iqtig:get_status_document($protocol/case, 'WARNING', 'WARNING')}">
							<xsl:copy-of select="$protocol_header/error"/>
						</status>
					</xsl:when>
							<xsl:otherwise>
								<status V="{iqtig:get_status($protocol/case, true())}">
									<xsl:copy-of select="$protocol_header/error"/>
								</status>
							</xsl:otherwise>
						</xsl:choose>
					</validation_item>
				</validation_provider>
			</xsl:if>
			<xsl:apply-templates mode="copy" select="node() | @*"/>
		</protocol>
	</xsl:template>
	<xsl:template match="validation_provider[@registration=$provider_registration]" mode="copy">
		<validation_provider>
			<xsl:apply-templates mode="copy" select="node() | @*"/>	
			<validation_item V="Spezifikation" c_date="{$c_date}" check_tool="{$tool_version}" id="{$validation_id}">
				<xsl:choose>
					<xsl:when test="$protocol_header/error[./rule_type/@V='H']">
						<status V="{iqtig:get_status_document($protocol/case, 'ERROR', 'ERROR')}">
							<xsl:copy-of select="$protocol_header/error"/>
						</status>
					</xsl:when>
					<xsl:when test="$protocol_header/error[./rule_type/@V='W']">
						<status V="{iqtig:get_status_document($protocol/case, 'WARNING', 'WARNING')}">
							<xsl:copy-of select="$protocol_header/error"/>
						</status>
					</xsl:when>
					<xsl:otherwise>
						<status V="{iqtig:get_status($protocol/case, true())}">
							<xsl:copy-of select="$protocol_header/error"/>
						</status>
					</xsl:otherwise>
				</xsl:choose>
			</validation_item>		
		</validation_provider>
	</xsl:template>	
	<xsl:template match="status_document" mode="copy">
		<xsl:choose>
			<xsl:when test="$protocol_header/error/rule_type[@V = 'H']">
				<status_document V="ERROR"/>
			</xsl:when>
			<xsl:when test="$protocol_header/error">
				<status_document V="{iqtig:get_status_document($protocol/case, @V, 'WARNING')}"/>
			</xsl:when>
			<xsl:otherwise>
				<status_document V="{iqtig:get_status_document($protocol/case, @V, 'OK')}"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="status_case" mode="copy">
		<xsl:variable name="case_id" select="generate-id(parent::protocol/parent::case_admin/parent::case)"/>
		<status_case V="{iqtig:get_status_case($protocol/case[@id = $case_id], @V)}"/>
	</xsl:template>
	<xsl:template match="modification_dttm" mode="copy">
		<modification_dttm V="{$c_date}"/>
	</xsl:template>
	<xsl:template match="node() | @*" mode="copy">
		<xsl:copy>
			<xsl:apply-templates mode="copy" select="node() | @*"/>
		</xsl:copy>
	</xsl:template>
	<xsl:template match="case">	
	<xsl:if test="$prechecks_ok">
		<xsl:variable name="cases_module" select="parent::cases/@module"/>
		<case id="{generate-id(.)}">
			<!-- nur Anker/workaround fuer PseudoProcedure  -->
			<xsl:if test="true()">
				<xsl:apply-templates mode="specific" select="."/>
				<xsl:if test="case_admin/module/@V != $cases_module">
					<error>
						<rule_id V="1001008"/>
						<rule_type V="H"/>
						<error_message V="Das Modul {case_admin/module/@V} im Element case_admin entspricht nicht dem im cases-Element festgelegten Modul."/>
					</error>
				</xsl:if>
				<xsl:if test="case_admin/action/@V != 'delete'">
					<!-- Pruefung 52 -->
					<xsl:if test="not(iqtig:exists(./qs_data/@module))">
						<error>
							<error_type V="EXPORT"/>
							<rule_id V="1001026"/>
							<rule_type V="H"/>
							<error_message V="Bei Vorgängen, deren Action auf 'create' oder 'update' steht, muss das Element qs_data vorhanden sein."/>
						</error>
					</xsl:if>			
					<xsl:if test="qs_data/@module != $cases_module">
						<error>
							<rule_id V="1001009"/>
							<rule_type V="H"/>
							<error_message V="Der Wert '{qs_data/@module}' des Attributs module im Element qs_data entspricht nicht dem im cases-Element festgelegten Modul."/>
						</error>
					</xsl:if>
					<!--Prüfung 171-->
					<xsl:if test="/root/body/data_container/cases/case/qs_data/@module = ('F_NW', 'F_SA', 'F_SA23') and iqtig:compare(count(//ARTNACHWEIS[./@V = '2']),'1','&gt;')">
						<error>
							<error_type V="EXPORT"/>
							<rule_id V="1001051"/>
							<rule_type V="H"/>
							<error_message V="Es darf nur ein jährlicher Nachweis nach § 6 Abs. 1 Satz 1 im Vorgang enthalten sein. Sollten Änderungen am Nachweis erforderlich sein, ist der bereits gelieferte Nachweis zu korrigieren bzw. zu ersetzen."/>
						</error>
					</xsl:if>
					<!--Prüfung 172-->
					<xsl:if test="starts-with(/root/header[1]/document[1]/software[1]/specification[1]/@V,'2024') and /root/body/data_container/cases/case/qs_data/@module = ('F_NW', 'F_SA', 'F_SA23') and not(iqtig:compare(count(//ARTNACHWEIS[./@V = '1']),'1','='))">
						<error>
							<error_type V="EXPORT"/>
							<rule_id V="1001052"/>
							<rule_type V="H"/>
							<error_message V="{concat(&quot;Es muss genau eine Erstanmeldung geben. Dieser Datensatz enthält aber &quot;,count(//ARTNACHWEIS[./@V = &quot;1&quot;]),&quot; Erstanmeldungen.&quot;)}"/>
						</error>
					</xsl:if>
					<!-- Prüfung 176 -->
					<!-- isOrderByTime() and and STICHTAG_AE_distinct()mit xsl:variable name="prechecks_ok" -->
					<xsl:if test="/root/body/data_container/cases/case/qs_data/@module = ('F_NW', 'F_SA', 'F_SA23') and exists(/root/body/data_container/cases/case/qs_data/B/bogen/C[position() != 1]//ARTNACHWEIS[./@V = '1'])">
						<error>
							<error_type V="EXPORT"/>
							<rule_id V="1001056"/>
							<rule_type V="H"/>
							<error_message V="Wenn eine Erstanmeldung im Vorgang enthalten ist, dann muss die Erstanmeldung die erste Checkliste in den zeitlich sortierten Checklisten sein."/>
						</error>
					</xsl:if>
					<!-- Prüfung 177 -->
					<!-- isOrderByTime() and and STICHTAG_AE_distinct()mit xsl:variable name="prechecks_ok" -->
					<xsl:if test="/root/body/data_container/cases/case/qs_data/@module = ('F_NW', 'F_SA', 'F_SA23') and exists(//ARTNACHWEIS[./@V='3' and not(./ancestor::C/preceding-sibling::*[1]//ABMELD[./@V  = '1'])])">
						<error>
							<error_type V="EXPORT"/>
							<rule_id V="1001057"/>
							<rule_type V="H"/>
							<error_message V="{concat(&quot;Es gibt mit Checkliste &quot;, string-join(//ARTNACHWEIS[./@V='3' and not(./ancestor::C/preceding-sibling::*[1]//ABMELD[./@V  = '1'])]/ancestor::C//LFDCHL/@V,&quot;, &quot;),&quot; eine Wiederanmeldung, obwohl die vorherige Checkliste &quot;,string-join(//ARTNACHWEIS[./@V='3' and not(./ancestor::C/preceding-sibling::*[1]//ABMELD[./@V  =  '1'])]/ancestor::C/preceding-sibling::*[1]//LFDCHL/@V,&quot;, &quot;),&quot; keine Abmeldung war.&quot;)}"/>
						</error>
					</xsl:if>
					<!-- Prüfung 178 -->
					<!-- isOrderByTime() and and STICHTAG_AE_distinct()mit xsl:variable name="prechecks_ok" -->
					<xsl:if test="/root/body/data_container/cases/case/qs_data/@module = ('F_NW', 'F_SA', 'F_SA23')and exists(//ABMELD[./@V  = '1' and ./ancestor::C/following-sibling::*[1] and not(./ancestor::C/following-sibling::*[1]//ARTNACHWEIS[./@V='3'])])">
						<error>
							<error_type V="EXPORT"/>
							<rule_id V="1001058"/>
							<rule_type V="H"/>
							<error_message V="{concat(&quot;Der Nachfolger einer Abmeldung muss eine Wiederanmeldung sein. Checkliste &quot;, string-join(//ABMELD[./@V  = '1' and ./ancestor::C/following-sibling::*[1] and not(./ancestor::C/following-sibling::*[1]//ARTNACHWEIS[./@V='3'])]/ancestor::C/following-sibling::*[1]//LFDCHL/@V,&quot;, &quot;),&quot; ist aber keine Wiederanmeldung.&quot;)}"/>
						</error>
					</xsl:if>
				<!--closing delete -->
				</xsl:if>
			<!--closing anker -->
			<xsl:if test="iqtig:exists(./parent::*/@pseud_procedure)">
						<xsl:choose>
							<xsl:when test="./parent::*/@pseud_procedure = 'undefined'">
								<xsl:if test="./parent::*/@module != 'F_NW' and ./parent::*/@module != 'F_SA' and ./parent::*/@module != 'F_SA23' and ./parent::*/@module != 'FFXE'">
									<error>
										<error_type V="EXPORT"/>
										<rule_id V="1001015"/>
										<rule_type V="H"/>
										<list V="{concat('data_container', iqtig:get_position_suffix(./parent::*/parent::data_container), '/cases', iqtig:get_position_suffix(parent::cases))}"/>
										<error_message V="Das angegebene Modul {./parent::*/@module} gehört nicht zum Verfahren undefined."/>
									</error>
								</xsl:if>
							</xsl:when>
							<xsl:otherwise/>
						</xsl:choose>
					</xsl:if>
				</xsl:if>
		</case>
	<!--closing prechecks_ok -->
	</xsl:if>
	</xsl:template>
	<xsl:template match="origination_dttm" mode="check_date">
		<!-- pruefung 68 (nur in der QSDOK und NICHT in oKFE aktiviert)-->
		<xsl:if test="/root/header/document/data_flow/@V = 'LE_LVKK' and iqtig:EINSNICHTIN(/root/body/data_container/cases/case/case_admin/module, ('F_NW'))">
			<error>
				<rule_id V="1019003"/>
				<rule_type V="H"/>
				<error_message V="{concat('Der Export von ',string-join(iqtig:value-except(/root/body/data_container/cases/case/case_admin/module/@V,('F_NW')),', '),' ist mit dem Datenfluss ',xs:string(/root/header/document/data_flow/@V),' (//data_flow/@V) nicht zulässig.')}"/>
			</error>
		</xsl:if>
		<xsl:if test="/root/header/document/data_flow/@V = 'LE_BAS' and iqtig:EINSNICHTIN(/root/body/data_container/cases/case/case_admin/module, ('F_SA','F_SA23','FFXE'))">
			<error>
				<rule_id V="1019003"/>
				<rule_type V="H"/>
				<error_message V="{concat('Der Export von ',string-join(iqtig:value-except(/root/body/data_container/cases/case/case_admin/module/@V,('F_SA','F_SA23','FFXE')),', '),' ist mit dem Datenfluss ',xs:string(/root/header/document/data_flow/@V),' (//data_flow/@V) nicht zulässig.')}"/>
			</error>
		</xsl:if>
		<xsl:if test="not(@V castable as xs:dateTime)">
			<error>
				<error_type V="WERT"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes origination_dttm ist kein gültiges Datum."/>
			</error>
		</xsl:if>
		<xsl:if test="(@V castable as xs:dateTime) and (../modification_dttm/@V castable as xs:dateTime) and (xs:dateTime(@V) &gt; xs:dateTime(../modification_dttm/@V))">
			<error>
				<rule_id V="1001007"/>
				<rule_type V="W"/>
				<error_message V="Das Erstelldatum ({@V}) liegt nach dem Modifikationsdatum ({../modification_dttm/@V})."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="modification_dttm" mode="check_date">
		<xsl:if test="not(@V castable as xs:dateTime)">
			<error>
				<error_type V="WERT"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes modification_dttm ist kein gültiges Datum."/>
			</error>
		</xsl:if>
	</xsl:template>
<xsl:template match="case[$prechecks_ok and not(case_admin/action/@V = 'delete') and not(qs_data/@xsi:type = 'qs_data_mds_type') and (qs_data/@module = 'F_NW' or qs_data/@module = 'F_SA' or qs_data/@module = 'F_SA23')]" mode="specific">
		<xsl:variable name="value_errors">
			<xsl:apply-templates mode="valuesFFX" select="qs_data/B/felder/*"/>
			<xsl:apply-templates mode="valuesFFX" select="qs_data/B/bogen/C/felder/*"/>
		</xsl:variable>
		<xsl:copy-of select="$value_errors/error"/>
		<xsl:apply-templates mode="formsFFX" select="qs_data/B"/>
		<xsl:apply-templates mode="rulesFFX" select="qs_data/B">
			<xsl:with-param name="blacklist_ids" select="$value_errors/blacklist/id"/>
		</xsl:apply-templates>
		<xsl:apply-templates mode="formsFFX" select="qs_data/B/bogen/C"/>
		<xsl:apply-templates mode="rulesFFX" select="qs_data/B/bogen/C">
			<xsl:with-param name="blacklist_ids" select="$value_errors/blacklist/id"/>
		</xsl:apply-templates>
	</xsl:template>
	<xsl:template match="B" mode="rulesFFX">
		<xsl:param name="blacklist_ids"/>
	</xsl:template>
	<xsl:template match="B" mode="formsFFX">
		<xsl:if test="count(bogen/C) &lt; 1">
			<error>
				<error_type V="TDS"/>
				<rule_id V="1001010"/>
				<rule_type V="H"/>
				<list V="{iqtig:bogen(.)}"/>
				<error_message V="Erforderlicher Teildatensatz C (&quot;Checkliste&quot;) existiert nicht."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="C" mode="rulesFFX">
		<xsl:param name="blacklist_ids"/>
		<!-- FFX:C: (MINFAIM = LEER ODER MINFAIM <> 0) UND ANFVOLLSTA <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '18908']))">
			<xsl:if test="((iqtig:compare(felder/MINFAIM/@V, '', '=') or iqtig:compare(felder/MINFAIM/@V, 0, '!=')) and iqtig:compare(felder/ANFVOLLSTA/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="18908"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/MINFAIM)}|{iqtig:feld(felder/ANFVOLLSTA)}"/>
					<error_message V="&quot;Das Krankenhaus verfügt mindestens über die Fachabteilung Innere Medizin am Standort&quot; ist nicht &quot;nein&quot; [0], obwohl &quot;Die Anforderungen gemäß § 10 Abs. 2 QSFFx-RL (Ausnahmetatbestand) sind vollständig erfüllt&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (MINFAIM <> LEER) UND (MINFAIM = 0 UND ANFVOLLSTA = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '19585']))">
			<xsl:if test="(iqtig:compare(felder/MINFAIM/@V, '', '!=') and (iqtig:compare(felder/MINFAIM/@V, 0, '=') and iqtig:compare(felder/ANFVOLLSTA/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="19585"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/MINFAIM)}|{iqtig:feld(felder/ANFVOLLSTA)}"/>
					<error_message V="&quot;Das Krankenhaus verfügt mindestens über die Fachabteilung Innere Medizin am Standort&quot; ist &quot;nein&quot; [0], obwohl &quot;Die Anforderungen gemäß § 10 Abs. 2 QSFFx-RL (Ausnahmetatbestand) sind vollständig erfüllt&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (GERIKOMP <> LEER) UND (GERIKOMP = 0 UND ANFVOLLSTB = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '19810']))">
			<xsl:if test="(iqtig:compare(felder/GERIKOMP/@V, '', '!=') and (iqtig:compare(felder/GERIKOMP/@V, 0, '=') and iqtig:compare(felder/ANFVOLLSTB/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="19810"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/GERIKOMP)}|{iqtig:feld(felder/ANFVOLLSTB)}"/>
					<error_message V="&quot;Für Patienten mit positivem geriatrischen Screening ist täglich &#10;geriatrische Kompetenz für die perioperative Versorgung gewährleistet&quot; ist &quot;nein&quot; [0], obwohl &quot;Die Anforderungen gemäß § 12 Abs. 1 QSFFx-RL (Übergangsregelung zur geriatrischen Versorgung) sind erfüllt&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (AENDMELD <> LEER) UND (AENDMELD = 1 UND STICHTAGAE = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '19820']))">
			<xsl:if test="(iqtig:compare(felder/AENDMELD/@V, '', '!=') and (iqtig:compare(felder/AENDMELD/@V, 1, '=') and iqtig:compare(felder/STICHTAGAE/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="19820"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/STICHTAGAE)}"/>
					<error_message V="&quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist &quot;ja&quot; [1], obwohl &quot;Datum des Eintretens der Nichterfüllung bzw. der Wiedererfüllung&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (AENDMELD = LEER ODER AENDMELD <> 1) UND STICHTAGAE <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '19822']))">
			<xsl:if test="((iqtig:compare(felder/AENDMELD/@V, '', '=') or iqtig:compare(felder/AENDMELD/@V, 1, '!=')) and iqtig:compare(felder/STICHTAGAE/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="19822"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/STICHTAGAE)}"/>
					<error_message V="&quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;Datum des Eintretens der Nichterfüllung bzw. der Wiedererfüllung&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (GERIKOMP = LEER ODER GERIKOMP <> 0) UND ANFVOLLSTB <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '19878']))">
			<xsl:if test="((iqtig:compare(felder/GERIKOMP/@V, '', '=') or iqtig:compare(felder/GERIKOMP/@V, 0, '!=')) and iqtig:compare(felder/ANFVOLLSTB/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="19878"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/GERIKOMP)}|{iqtig:feld(felder/ANFVOLLSTB)}"/>
					<error_message V="&quot;Für Patienten mit positivem geriatrischen Screening ist täglich &#10;geriatrische Kompetenz für die perioperative Versorgung gewährleistet&quot; ist nicht &quot;nein&quot; [0], obwohl &quot;Die Anforderungen gemäß § 12 Abs. 1 QSFFx-RL (Übergangsregelung zur geriatrischen Versorgung) sind erfüllt&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA = LEER ODER ANFTRAUMA <> 1) UND STRUKTPROZ <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20455']))">
			<xsl:if test="((iqtig:compare(felder/ANFTRAUMA/@V, '', '=') or iqtig:compare(felder/ANFTRAUMA/@V, 1, '!=')) and iqtig:compare(felder/STRUKTPROZ/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20455"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/STRUKTPROZ)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;A - Strukturen und Prozesse:&#13;&#10;Erfüllung aller 12 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA = LEER ODER ANFTRAUMA <> 1) UND AERZTLEIT <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20456']))">
			<xsl:if test="((iqtig:compare(felder/ANFTRAUMA/@V, '', '=') or iqtig:compare(felder/ANFTRAUMA/@V, 1, '!=')) and iqtig:compare(felder/AERZTLEIT/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20456"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/AERZTLEIT)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;B - Personal - Ärztliche Leitungsebene: &#13;&#10;Erfüllung aller 2 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA = LEER ODER ANFTRAUMA <> 1) UND BATSCHOCK <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20457']))">
			<xsl:if test="((iqtig:compare(felder/ANFTRAUMA/@V, '', '=') or iqtig:compare(felder/ANFTRAUMA/@V, 1, '!=')) and iqtig:compare(felder/BATSCHOCK/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20457"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/BATSCHOCK)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;B - Personal - Basisteam im Schockraum:&#13;&#10;Erfüllung aller 8 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA = LEER ODER ANFTRAUMA <> 1) UND ERWSCHOCKT <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20458']))">
			<xsl:if test="((iqtig:compare(felder/ANFTRAUMA/@V, '', '=') or iqtig:compare(felder/ANFTRAUMA/@V, 1, '!=')) and iqtig:compare(felder/ERWSCHOCKT/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20458"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/ERWSCHOCKT)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;B - Personal - Erweitertes Schockraumteam:&#13;&#10;Erfüllung aller 13 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA = LEER ODER ANFTRAUMA <> 1) UND FAKVERFPERS <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20459']))">
			<xsl:if test="((iqtig:compare(felder/ANFTRAUMA/@V, '', '=') or iqtig:compare(felder/ANFTRAUMA/@V, 1, '!=')) and iqtig:compare(felder/FAKVERFPERS/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20459"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/FAKVERFPERS)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;B - Personal - Fakultativ verfügbares Personal:&#13;&#10;Erfüllung aller 3 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA = LEER ODER ANFTRAUMA <> 1) UND NOTAUFN <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20460']))">
			<xsl:if test="((iqtig:compare(felder/ANFTRAUMA/@V, '', '=') or iqtig:compare(felder/ANFTRAUMA/@V, 1, '!=')) and iqtig:compare(felder/NOTAUFN/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20460"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/NOTAUFN)}|{iqtig:feld(felder/ANFTRAUMA)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;C - Räumliche Anforderungen - Notaufnahme:&#13;&#10;Erfüllung aller 8 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA = LEER ODER ANFTRAUMA <> 1) UND OPABT <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20461']))">
			<xsl:if test="((iqtig:compare(felder/ANFTRAUMA/@V, '', '=') or iqtig:compare(felder/ANFTRAUMA/@V, 1, '!=')) and iqtig:compare(felder/OPABT/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20461"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/OPABT)}|{iqtig:feld(felder/ANFTRAUMA)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;C - Räumliche Anforderungen - Operationsabteilung:&#13;&#10;Erfüllung der Mindestanforderung gemäß dem Anhang zu Anlage 3&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA = LEER ODER ANFTRAUMA <> 1) UND PERSINTENSIV <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20463']))">
			<xsl:if test="((iqtig:compare(felder/ANFTRAUMA/@V, '', '=') or iqtig:compare(felder/ANFTRAUMA/@V, 1, '!=')) and iqtig:compare(felder/PERSINTENSIV/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20463"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/PERSINTENSIV)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;D - Personelle Ausstattung der Intensivstation:&#13;&#10;Erfüllung aller 8 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA = LEER ODER ANFTRAUMA <> 1) UND APPAUSST <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20464']))">
			<xsl:if test="((iqtig:compare(felder/ANFTRAUMA/@V, '', '=') or iqtig:compare(felder/ANFTRAUMA/@V, 1, '!=')) and iqtig:compare(felder/APPAUSST/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20464"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/APPAUSST)}|{iqtig:feld(felder/ANFTRAUMA)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;E - Ausstattung/apparative Ausstattung:&#13;&#10;Erfüllung aller 18 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA = LEER ODER ANFTRAUMA <> 1) UND APPAUSSTOP <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20465']))">
			<xsl:if test="((iqtig:compare(felder/ANFTRAUMA/@V, '', '=') or iqtig:compare(felder/ANFTRAUMA/@V, 1, '!=')) and iqtig:compare(felder/APPAUSSTOP/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20465"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/APPAUSSTOP)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;E - Ausstattung/apparative Ausstattung:&#13;&#10;Erfüllung aller 3 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA = LEER ODER ANFTRAUMA <> 0) UND MINFAA <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20466']))">
			<xsl:if test="((iqtig:compare(felder/ANFTRAUMA/@V, '', '=') or iqtig:compare(felder/ANFTRAUMA/@V, 0, '!=')) and iqtig:compare(felder/MINFAA/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20466"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/MINFAA)}|{iqtig:feld(felder/ANFTRAUMA)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist nicht &quot;nein&quot; [0], obwohl &quot;Das Krankenhaus verfügt mindestens über die Fachabteilung Chirurgie oder&#13;&#10;Unfallchirurgie oder Allgemeine Chirurgie oder Orthopädie oder&#13;&#10;Orthopädie und Unfallchirurgie am Standort&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA = LEER ODER ANFTRAUMA <> 0) UND MINFAIM <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20467']))">
			<xsl:if test="((iqtig:compare(felder/ANFTRAUMA/@V, '', '=') or iqtig:compare(felder/ANFTRAUMA/@V, 0, '!=')) and iqtig:compare(felder/MINFAIM/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20467"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/MINFAIM)}|{iqtig:feld(felder/ANFTRAUMA)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist nicht &quot;nein&quot; [0], obwohl &quot;Das Krankenhaus verfügt mindestens über die Fachabteilung Innere Medizin am Standort&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA = LEER ODER ANFTRAUMA <> 0) UND NOTFVERANT <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20468']))">
			<xsl:if test="((iqtig:compare(felder/ANFTRAUMA/@V, '', '=') or iqtig:compare(felder/ANFTRAUMA/@V, 0, '!=')) and iqtig:compare(felder/NOTFVERANT/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20468"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/NOTFVERANT)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist nicht &quot;nein&quot; [0], obwohl &quot;Es sind jeweils ein für die Notfallversorgung verantwortlicher &#10;Arzt und eine Pflegekraft benannt, die fachlich und &#10;organisatorisch eindeutig der Versorgung von Notfällen zugeordnet und im Bedarfsfall verfügbar sind&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA = LEER ODER ANFTRAUMA <> 0) UND FAVERFUEGB <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20472']))">
			<xsl:if test="((iqtig:compare(felder/ANFTRAUMA/@V, '', '=') or iqtig:compare(felder/ANFTRAUMA/@V, 0, '!=')) and iqtig:compare(felder/FAVERFUEGB/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20472"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/FAVERFUEGB)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist nicht &quot;nein&quot; [0], obwohl &quot;Es ist jeweils ein Facharzt im Gebiet Innere Medizin,&#10;Chirurgie und Anästhesie innerhalb von maximal 30 Minuten am Patienten verfügbar&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA = LEER ODER ANFTRAUMA <> 0) UND INTENBETT <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20473']))">
			<xsl:if test="((iqtig:compare(felder/ANFTRAUMA/@V, '', '=') or iqtig:compare(felder/ANFTRAUMA/@V, 0, '!=')) and iqtig:compare(felder/INTENBETT/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20473"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/INTENBETT)}|{iqtig:feld(felder/ANFTRAUMA)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist nicht &quot;nein&quot; [0], obwohl &quot;Die Intensivstation verfügt über mindestens sechs Intensivtherapiebetten&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA = LEER ODER ANFTRAUMA <> 0) UND INTENBBEATM <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20474']))">
			<xsl:if test="((iqtig:compare(felder/ANFTRAUMA/@V, '', '=') or iqtig:compare(felder/ANFTRAUMA/@V, 0, '!=')) and iqtig:compare(felder/INTENBBEATM/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20474"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/INTENBBEATM)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist nicht &quot;nein&quot; [0], obwohl &quot;Mindestens drei Intensivtherapiebetten sind zur Versorgung &#10;beatmeter Patienten ausgestattet&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA = LEER ODER ANFTRAUMA <> 0) UND SYSBEHAND <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20475']))">
			<xsl:if test="((iqtig:compare(felder/ANFTRAUMA/@V, '', '=') or iqtig:compare(felder/ANFTRAUMA/@V, 0, '!=')) and iqtig:compare(felder/SYSBEHAND/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20475"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/SYSBEHAND)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist nicht &quot;nein&quot; [0], obwohl &quot;Es kommt ein strukturiertes und validiertes System zur Behandlungspriorisierung bei der Erstaufnahme von Notfallpatienten zur Anwendung&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA = LEER ODER ANFTRAUMA <> 0) UND SCHOCK <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20476']))">
			<xsl:if test="((iqtig:compare(felder/ANFTRAUMA/@V, '', '=') or iqtig:compare(felder/ANFTRAUMA/@V, 0, '!=')) and iqtig:compare(felder/SCHOCK/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20476"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/SCHOCK)}|{iqtig:feld(felder/ANFTRAUMA)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist nicht &quot;nein&quot; [0], obwohl &quot;Es ist ein Schockraum verfügbar&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA = LEER ODER ANFTRAUMA <> 0) UND VERFUEGCT <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20477']))">
			<xsl:if test="((iqtig:compare(felder/ANFTRAUMA/@V, '', '=') or iqtig:compare(felder/ANFTRAUMA/@V, 0, '!=')) and iqtig:compare(felder/VERFUEGCT/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20477"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/VERFUEGCT)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist nicht &quot;nein&quot; [0], obwohl &quot;Die 24-stündige Verfügbarkeit von Computertomographie ist sichergestellt&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA = LEER ODER ANFTRAUMA <> 0) UND WEITERVERLUFT <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20478']))">
			<xsl:if test="((iqtig:compare(felder/ANFTRAUMA/@V, '', '=') or iqtig:compare(felder/ANFTRAUMA/@V, 0, '!=')) and iqtig:compare(felder/WEITERVERLUFT/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20478"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/WEITERVERLUFT)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist nicht &quot;nein&quot; [0], obwohl &quot;Es besteht die Möglichkeit der Weiterverlegung eines Notfallpatienten auf dem Luftweg in ein Krankenhaus der Basisnotfallversorgung oder einer höheren Stufe&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: AENDMELD <> LEER UND ANMELDEJ <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20511']))">
			<xsl:if test="(iqtig:compare(felder/AENDMELD/@V, '', '!=') and iqtig:compare(felder/ANMELDEJ/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20511"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANMELDEJ)}|{iqtig:feld(felder/AENDMELD)}"/>
					<error_message V="Jedes der Felder &quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; und &quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; ist ausgefüllt"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ <> LEER) UND (ANMELDEJ = 1 UND STICHTAG = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20574']))">
			<xsl:if test="(iqtig:compare(felder/ANMELDEJ/@V, '', '!=') and (iqtig:compare(felder/ANMELDEJ/@V, 1, '=') and iqtig:compare(felder/STICHTAG/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20574"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANMELDEJ)}|{iqtig:feld(felder/STICHTAG)}"/>
					<error_message V="&quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; ist &quot;ja&quot; [1], obwohl &quot;Stichtag&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ <> LEER) UND (ANMELDEJ = 1 UND ANFTRAUMA = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20581']))">
			<xsl:if test="(iqtig:compare(felder/ANMELDEJ/@V, '', '!=') and (iqtig:compare(felder/ANMELDEJ/@V, 1, '=') and iqtig:compare(felder/ANFTRAUMA/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20581"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANMELDEJ)}|{iqtig:feld(felder/ANFTRAUMA)}"/>
					<error_message V="&quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; ist &quot;ja&quot; [1], obwohl &quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ <> LEER) UND (ANMELDEJ = 1 UND FAORGEINHEIT = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20582']))">
			<xsl:if test="(iqtig:compare(felder/ANMELDEJ/@V, '', '!=') and (iqtig:compare(felder/ANMELDEJ/@V, 1, '=') and iqtig:compare(felder/FAORGEINHEIT/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20582"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANMELDEJ)}|{iqtig:feld(felder/FAORGEINHEIT)}"/>
					<error_message V="&quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; ist &quot;ja&quot; [1], obwohl &quot;Die Versorgung der Patienten erfolgt in einer ärztlich geleiteten Fachabteilung, die eine fachlich unabhängige, abgrenzbare und organisatorisch eigenständige Organisationseinheit am Standort des Krankenhauses ist&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ <> LEER) UND (ANMELDEJ = 1 UND ANLFA = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20583']))">
			<xsl:if test="(iqtig:compare(felder/ANMELDEJ/@V, '', '!=') and (iqtig:compare(felder/ANMELDEJ/@V, 1, '=') and iqtig:compare(felder/ANLFA/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20583"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANLFA)}|{iqtig:feld(felder/ANMELDEJ)}"/>
					<error_message V="&quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; ist &quot;ja&quot; [1], obwohl &quot;Die Durchführung der mit den Kombinationen aus Diagnosen &#10;und Prozeduren nach Anlage 1 QSFFx-RL beschriebenen Operationen erfolgt &#10;durch oder unter Anleitung und Aufsicht einer Fachärztin oder eines Facharztes für Chirurgie&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ <> LEER) UND (ANMELDEJ = 1 UND VERSORGPRAES = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20584']))">
			<xsl:if test="(iqtig:compare(felder/ANMELDEJ/@V, '', '!=') and (iqtig:compare(felder/ANMELDEJ/@V, 1, '=') and iqtig:compare(felder/VERSORGPRAES/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20584"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANMELDEJ)}|{iqtig:feld(felder/VERSORGPRAES)}"/>
					<error_message V="&quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; ist &quot;ja&quot; [1], obwohl &quot;Die ärztliche Versorgung in der Fachabteilung ist durch eine &#10;täglich 24 stündige Arztpräsenz im Krankenhaus (Bereitschaftsdienst möglich) sichergestellt, die auch eine jederzeitige operative Patientenversorgung gewährleistet&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ <> LEER) UND (ANMELDEJ = 1 UND AUSSENDO = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20585']))">
			<xsl:if test="(iqtig:compare(felder/ANMELDEJ/@V, '', '!=') and (iqtig:compare(felder/ANMELDEJ/@V, 1, '=') and iqtig:compare(felder/AUSSENDO/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20585"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANMELDEJ)}|{iqtig:feld(felder/AUSSENDO)}"/>
					<error_message V="&quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; ist &quot;ja&quot; [1], obwohl &quot;Die Einrichtung und Ausstattung des Operationssaals lässt &#10;sowohl osteosynthetische als auch endoprothetische &#10;Versorgungen zu. Entsprechende Implantate und Instrumente stehen jederzeit zur Verfügung&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ <> LEER) UND (ANMELDEJ = 1 UND GERIKOMP = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20586']))">
			<xsl:if test="(iqtig:compare(felder/ANMELDEJ/@V, '', '!=') and (iqtig:compare(felder/ANMELDEJ/@V, 1, '=') and iqtig:compare(felder/GERIKOMP/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20586"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANMELDEJ)}|{iqtig:feld(felder/GERIKOMP)}"/>
					<error_message V="&quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; ist &quot;ja&quot; [1], obwohl &quot;Für Patienten mit positivem geriatrischen Screening ist täglich &#10;geriatrische Kompetenz für die perioperative Versorgung gewährleistet&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ <> LEER) UND (ANMELDEJ = 1 UND PHYSATEM = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20587']))">
			<xsl:if test="(iqtig:compare(felder/ANMELDEJ/@V, '', '!=') and (iqtig:compare(felder/ANMELDEJ/@V, 1, '=') and iqtig:compare(felder/PHYSATEM/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20587"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANMELDEJ)}|{iqtig:feld(felder/PHYSATEM)}"/>
					<error_message V="&quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; ist &quot;ja&quot; [1], obwohl &quot;Physiotherapie durch einen Physiotherapeuten/ eine &#10;Physiotherapeutin steht täglich für jeden Patienten zur &#10;Atemgymnastik und frühzeitigen Mobilisierung ab dem ersten postoperativen Tag zur Verfügung&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ <> LEER) UND (ANMELDEJ = 1 UND SOPEINW = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20588']))">
			<xsl:if test="(iqtig:compare(felder/ANMELDEJ/@V, '', '!=') and (iqtig:compare(felder/ANMELDEJ/@V, 1, '=') and iqtig:compare(felder/SOPEINW/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20588"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/SOPEINW)}|{iqtig:feld(felder/ANMELDEJ)}"/>
					<error_message V="&quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; ist &quot;ja&quot; [1], obwohl &quot;Der Krankenhausstandort verfügt über die SOP &quot;Besondere Situationen der Einwilligungsfähigkeit&quot;&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ <> LEER) UND (ANMELDEJ = 1 UND SOPPERI = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20589']))">
			<xsl:if test="(iqtig:compare(felder/ANMELDEJ/@V, '', '!=') and (iqtig:compare(felder/ANMELDEJ/@V, 1, '=') and iqtig:compare(felder/SOPPERI/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20589"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/SOPPERI)}|{iqtig:feld(felder/ANMELDEJ)}"/>
					<error_message V="&quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; ist &quot;ja&quot; [1], obwohl &quot;Der Krankenhausstandort verfügt über die SOP &quot;Perioperative &#10;Planung: Priorisierung von Eingriffen, Planung von OP Kapazitäten, Planung von OP-Teams&quot;&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ <> LEER) UND (ANMELDEJ = 1 UND SOPOPV = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20590']))">
			<xsl:if test="(iqtig:compare(felder/ANMELDEJ/@V, '', '!=') and (iqtig:compare(felder/ANMELDEJ/@V, 1, '=') and iqtig:compare(felder/SOPOPV/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20590"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/SOPOPV)}|{iqtig:feld(felder/ANMELDEJ)}"/>
					<error_message V="&quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; ist &quot;ja&quot; [1], obwohl &quot;Der Krankenhausstandort verfügt über die SOP &quot;Operationsverfahren&quot;&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ <> LEER) UND (ANMELDEJ = 1 UND SOPMED = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20591']))">
			<xsl:if test="(iqtig:compare(felder/ANMELDEJ/@V, '', '!=') and (iqtig:compare(felder/ANMELDEJ/@V, 1, '=') and iqtig:compare(felder/SOPMED/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20591"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/SOPMED)}|{iqtig:feld(felder/ANMELDEJ)}"/>
					<error_message V="&quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; ist &quot;ja&quot; [1], obwohl &quot;Der Krankenhausstandort verfügt über die SOP &quot;Umgang mit gerinnungshemmender Medikation&quot;&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ <> LEER) UND (ANMELDEJ = 1 UND SOPBLUT = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20592']))">
			<xsl:if test="(iqtig:compare(felder/ANMELDEJ/@V, '', '!=') and (iqtig:compare(felder/ANMELDEJ/@V, 1, '=') and iqtig:compare(felder/SOPBLUT/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20592"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/SOPBLUT)}|{iqtig:feld(felder/ANMELDEJ)}"/>
					<error_message V="&quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; ist &quot;ja&quot; [1], obwohl &quot;Der Krankenhausstandort verfügt über die SOP &quot;Patientenorientiertes Blutmanagement (PBM)&quot;&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ <> LEER) UND (ANMELDEJ = 1 UND SOPGERI = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20593']))">
			<xsl:if test="(iqtig:compare(felder/ANMELDEJ/@V, '', '!=') and (iqtig:compare(felder/ANMELDEJ/@V, 1, '=') and iqtig:compare(felder/SOPGERI/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20593"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/SOPGERI)}|{iqtig:feld(felder/ANMELDEJ)}"/>
					<error_message V="&quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; ist &quot;ja&quot; [1], obwohl &quot;Der Krankenhausstandort verfügt über die SOP &quot;Orthogeriatrische Zusammenarbeit für Patienten mit positivem geriatrischen Screening&quot;&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ <> LEER) UND (ANMELDEJ = 1 UND SOPPHYS = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20594']))">
			<xsl:if test="(iqtig:compare(felder/ANMELDEJ/@V, '', '!=') and (iqtig:compare(felder/ANMELDEJ/@V, 1, '=') and iqtig:compare(felder/SOPPHYS/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20594"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/SOPPHYS)}|{iqtig:feld(felder/ANMELDEJ)}"/>
					<error_message V="&quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; ist &quot;ja&quot; [1], obwohl &quot;Der Krankenhausstandort verfügt über die SOP &quot;Physiotherapeutische Maßnahmen&quot;&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (NOTFVERANT <> LEER) UND (NOTFVERANT = 1 UND NOTFZUSATZW = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20640']))">
			<xsl:if test="(iqtig:compare(felder/NOTFVERANT/@V, '', '!=') and (iqtig:compare(felder/NOTFVERANT/@V, 1, '=') and iqtig:compare(felder/NOTFZUSATZW/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20640"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/NOTFVERANT)}|{iqtig:feld(felder/NOTFZUSATZW)}"/>
					<error_message V="&quot;Es sind jeweils ein für die Notfallversorgung verantwortlicher &#10;Arzt und eine Pflegekraft benannt, die fachlich und &#10;organisatorisch eindeutig der Versorgung von Notfällen zugeordnet und im Bedarfsfall verfügbar sind&quot; ist &quot;ja&quot; [1], obwohl &quot;Der für die Notfallversorgung benannte Arzt verfügt über die Zusatzweiterbildung &quot;Klinische Akut- und Notfallmedizin&quot;&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (NOTFVERANT <> LEER) UND (NOTFVERANT = 1 UND NOTFPWEITERB = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20641']))">
			<xsl:if test="(iqtig:compare(felder/NOTFVERANT/@V, '', '!=') and (iqtig:compare(felder/NOTFVERANT/@V, 1, '=') and iqtig:compare(felder/NOTFPWEITERB/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20641"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/NOTFVERANT)}|{iqtig:feld(felder/NOTFPWEITERB)}"/>
					<error_message V="&quot;Es sind jeweils ein für die Notfallversorgung verantwortlicher &#10;Arzt und eine Pflegekraft benannt, die fachlich und &#10;organisatorisch eindeutig der Versorgung von Notfällen zugeordnet und im Bedarfsfall verfügbar sind&quot; ist &quot;ja&quot; [1], obwohl &quot;Die für die Notfallversorgung benannte Pflegekraft verfügt &#10;über die Weiterbildung &quot;Notfallpflege&quot;&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (NOTFVERANT <> LEER) UND (NOTFVERANT = 1 UND NOTFFORTB = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20642']))">
			<xsl:if test="(iqtig:compare(felder/NOTFVERANT/@V, '', '!=') and (iqtig:compare(felder/NOTFVERANT/@V, 1, '=') and iqtig:compare(felder/NOTFFORTB/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20642"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/NOTFFORTB)}|{iqtig:feld(felder/NOTFVERANT)}"/>
					<error_message V="&quot;Es sind jeweils ein für die Notfallversorgung verantwortlicher &#10;Arzt und eine Pflegekraft benannt, die fachlich und &#10;organisatorisch eindeutig der Versorgung von Notfällen zugeordnet und im Bedarfsfall verfügbar sind&quot; ist &quot;ja&quot; [1], obwohl &quot;Der für die Notfallversorgung benannte Arzt und die für die Notfallversorgung benannte Pflegekraft nehmen regelmäßig an &#10;fachspezifischen Fortbildungen für Notfallmedizin teil&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (NOTFVERANT = LEER ODER NOTFVERANT <> 1) UND NOTFZUSATZW <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20643']))">
			<xsl:if test="((iqtig:compare(felder/NOTFVERANT/@V, '', '=') or iqtig:compare(felder/NOTFVERANT/@V, 1, '!=')) and iqtig:compare(felder/NOTFZUSATZW/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20643"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/NOTFVERANT)}|{iqtig:feld(felder/NOTFZUSATZW)}"/>
					<error_message V="&quot;Es sind jeweils ein für die Notfallversorgung verantwortlicher &#10;Arzt und eine Pflegekraft benannt, die fachlich und &#10;organisatorisch eindeutig der Versorgung von Notfällen zugeordnet und im Bedarfsfall verfügbar sind&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;Der für die Notfallversorgung benannte Arzt verfügt über die Zusatzweiterbildung &quot;Klinische Akut- und Notfallmedizin&quot;&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (NOTFVERANT = LEER ODER NOTFVERANT <> 1) UND NOTFPWEITERB <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20644']))">
			<xsl:if test="((iqtig:compare(felder/NOTFVERANT/@V, '', '=') or iqtig:compare(felder/NOTFVERANT/@V, 1, '!=')) and iqtig:compare(felder/NOTFPWEITERB/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20644"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/NOTFVERANT)}|{iqtig:feld(felder/NOTFPWEITERB)}"/>
					<error_message V="&quot;Es sind jeweils ein für die Notfallversorgung verantwortlicher &#10;Arzt und eine Pflegekraft benannt, die fachlich und &#10;organisatorisch eindeutig der Versorgung von Notfällen zugeordnet und im Bedarfsfall verfügbar sind&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;Die für die Notfallversorgung benannte Pflegekraft verfügt &#10;über die Weiterbildung &quot;Notfallpflege&quot;&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (NOTFVERANT = LEER ODER NOTFVERANT <> 1) UND NOTFFORTB <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20645']))">
			<xsl:if test="((iqtig:compare(felder/NOTFVERANT/@V, '', '=') or iqtig:compare(felder/NOTFVERANT/@V, 1, '!=')) and iqtig:compare(felder/NOTFFORTB/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20645"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/NOTFFORTB)}|{iqtig:feld(felder/NOTFVERANT)}"/>
					<error_message V="&quot;Es sind jeweils ein für die Notfallversorgung verantwortlicher &#10;Arzt und eine Pflegekraft benannt, die fachlich und &#10;organisatorisch eindeutig der Versorgung von Notfällen zugeordnet und im Bedarfsfall verfügbar sind&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;Der für die Notfallversorgung benannte Arzt und die für die Notfallversorgung benannte Pflegekraft nehmen regelmäßig an &#10;fachspezifischen Fortbildungen für Notfallmedizin teil&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: AENDMELD <> LEER UND ABMELD <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20697']))">
			<xsl:if test="(iqtig:compare(felder/AENDMELD/@V, '', '!=') and iqtig:compare(felder/ABMELD/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20697"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ABMELD)}|{iqtig:feld(felder/AENDMELD)}"/>
					<error_message V="Jedes der Felder &quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; und &quot;Abmeldung vom Nachweisverfahren&quot; ist ausgefüllt"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: ANMELDEJ <> LEER UND ABMELD <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20701']))">
			<xsl:if test="(iqtig:compare(felder/ANMELDEJ/@V, '', '!=') and iqtig:compare(felder/ABMELD/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20701"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ABMELD)}|{iqtig:feld(felder/ANMELDEJ)}"/>
					<error_message V="Jedes der Felder &quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; und &quot;Abmeldung vom Nachweisverfahren&quot; ist ausgefüllt"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ERFMIND <> LEER UND ANFTRAUMA <> LEER UND MINFAA <> LEER UND MINFAIM <> LEER UND ANFVOLLSTA <> LEER UND NOTFVERANT <> LEER UND NOTFFORTB <> LEER UND FAVERFUEGB <> LEER UND INTENBETT <> LEER UND INTENBBEATM <> LEER UND SYSBEHAND <> LEER UND SCHOCK <> LEER UND VERFUEGCT <> LEER UND WEITERVERLUFT <> LEER UND STRUKTPROZ <> LEER UND AERZTLEIT <> LEER UND BATSCHOCK <> LEER UND ERWSCHOCKT <> LEER UND FAKVERFPERS <> LEER UND NOTAUFN <> LEER UND OPABT <> LEER UND PERSINTENSIV <> LEER UND APPAUSST <> LEER UND APPAUSSTOP <> LEER UND FAORGEINHEIT <> LEER UND ANLFA <> LEER UND VERSORGPRAES <> LEER UND AUSSENDO <> LEER UND GERIKOMP <> LEER UND ANFVOLLSTB <> LEER UND PHYSATEM <> LEER UND SOPEINW <> LEER UND SOPPERI <> LEER UND SOPOPV <> LEER UND SOPMED <> LEER UND SOPBLUT <> LEER UND SOPGERI <> LEER UND SOPPHYS <> LEER) UND (ERFMIND = 1 UND ((ANFTRAUMA = 0 UND (MINFAA = 0 ODER (MINFAIM = 0 UND ANFVOLLSTA = 0) ODER NOTFVERANT = 0 ODER NOTFFORTB = 0 ODER FAVERFUEGB = 0 ODER INTENBETT = 0 ODER INTENBBEATM = 0 ODER SYSBEHAND = 0 ODER SCHOCK = 0 ODER VERFUEGCT = 0 ODER WEITERVERLUFT = 0)) ODER (ANFTRAUMA = 1 UND (STRUKTPROZ = 0 ODER AERZTLEIT = 0 ODER BATSCHOCK = 0 ODER ERWSCHOCKT = 0 ODER FAKVERFPERS = 0 ODER NOTAUFN = 0 ODER OPABT = 0 ODER PERSINTENSIV = 0 ODER APPAUSST = 0 ODER APPAUSSTOP = 0)) ODER FAORGEINHEIT = 0 ODER ANLFA = 0 ODER VERSORGPRAES = 0 ODER AUSSENDO = 0 ODER (GERIKOMP = 0 UND ANFVOLLSTB = 0) ODER PHYSATEM = 0 ODER SOPEINW = 0 ODER SOPPERI = 0 ODER SOPOPV = 0 ODER SOPMED = 0 ODER SOPBLUT = 0 ODER SOPGERI = 0 ODER SOPPHYS = 0)) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20718']))">
			<xsl:if test="((iqtig:compare(felder/ERFMIND/@V, '', '!=') and iqtig:compare(felder/ANFTRAUMA/@V, '', '!=') and iqtig:compare(felder/MINFAA/@V, '', '!=') and iqtig:compare(felder/MINFAIM/@V, '', '!=') and iqtig:compare(felder/ANFVOLLSTA/@V, '', '!=') and iqtig:compare(felder/NOTFVERANT/@V, '', '!=') and iqtig:compare(felder/NOTFFORTB/@V, '', '!=') and iqtig:compare(felder/FAVERFUEGB/@V, '', '!=') and iqtig:compare(felder/INTENBETT/@V, '', '!=') and iqtig:compare(felder/INTENBBEATM/@V, '', '!=') and iqtig:compare(felder/SYSBEHAND/@V, '', '!=') and iqtig:compare(felder/SCHOCK/@V, '', '!=') and iqtig:compare(felder/VERFUEGCT/@V, '', '!=') and iqtig:compare(felder/WEITERVERLUFT/@V, '', '!=') and iqtig:compare(felder/STRUKTPROZ/@V, '', '!=') and iqtig:compare(felder/AERZTLEIT/@V, '', '!=') and iqtig:compare(felder/BATSCHOCK/@V, '', '!=') and iqtig:compare(felder/ERWSCHOCKT/@V, '', '!=') and iqtig:compare(felder/FAKVERFPERS/@V, '', '!=') and iqtig:compare(felder/NOTAUFN/@V, '', '!=') and iqtig:compare(felder/OPABT/@V, '', '!=') and iqtig:compare(felder/PERSINTENSIV/@V, '', '!=') and iqtig:compare(felder/APPAUSST/@V, '', '!=') and iqtig:compare(felder/APPAUSSTOP/@V, '', '!=') and iqtig:compare(felder/FAORGEINHEIT/@V, '', '!=') and iqtig:compare(felder/ANLFA/@V, '', '!=') and iqtig:compare(felder/VERSORGPRAES/@V, '', '!=') and iqtig:compare(felder/AUSSENDO/@V, '', '!=') and iqtig:compare(felder/GERIKOMP/@V, '', '!=') and iqtig:compare(felder/ANFVOLLSTB/@V, '', '!=') and iqtig:compare(felder/PHYSATEM/@V, '', '!=') and iqtig:compare(felder/SOPEINW/@V, '', '!=') and iqtig:compare(felder/SOPPERI/@V, '', '!=') and iqtig:compare(felder/SOPOPV/@V, '', '!=') and iqtig:compare(felder/SOPMED/@V, '', '!=') and iqtig:compare(felder/SOPBLUT/@V, '', '!=') and iqtig:compare(felder/SOPGERI/@V, '', '!=') and iqtig:compare(felder/SOPPHYS/@V, '', '!=')) and (iqtig:compare(felder/ERFMIND/@V, 1, '=') and ((iqtig:compare(felder/ANFTRAUMA/@V, 0, '=') and (iqtig:compare(felder/MINFAA/@V, 0, '=') or (iqtig:compare(felder/MINFAIM/@V, 0, '=') and iqtig:compare(felder/ANFVOLLSTA/@V, 0, '=')) or iqtig:compare(felder/NOTFVERANT/@V, 0, '=') or iqtig:compare(felder/NOTFFORTB/@V, 0, '=') or iqtig:compare(felder/FAVERFUEGB/@V, 0, '=') or iqtig:compare(felder/INTENBETT/@V, 0, '=') or iqtig:compare(felder/INTENBBEATM/@V, 0, '=') or iqtig:compare(felder/SYSBEHAND/@V, 0, '=') or iqtig:compare(felder/SCHOCK/@V, 0, '=') or iqtig:compare(felder/VERFUEGCT/@V, 0, '=') or iqtig:compare(felder/WEITERVERLUFT/@V, 0, '='))) or (iqtig:compare(felder/ANFTRAUMA/@V, 1, '=') and (iqtig:compare(felder/STRUKTPROZ/@V, 0, '=') or iqtig:compare(felder/AERZTLEIT/@V, 0, '=') or iqtig:compare(felder/BATSCHOCK/@V, 0, '=') or iqtig:compare(felder/ERWSCHOCKT/@V, 0, '=') or iqtig:compare(felder/FAKVERFPERS/@V, 0, '=') or iqtig:compare(felder/NOTAUFN/@V, 0, '=') or iqtig:compare(felder/OPABT/@V, 0, '=') or iqtig:compare(felder/PERSINTENSIV/@V, 0, '=') or iqtig:compare(felder/APPAUSST/@V, 0, '=') or iqtig:compare(felder/APPAUSSTOP/@V, 0, '='))) or iqtig:compare(felder/FAORGEINHEIT/@V, 0, '=') or iqtig:compare(felder/ANLFA/@V, 0, '=') or iqtig:compare(felder/VERSORGPRAES/@V, 0, '=') or iqtig:compare(felder/AUSSENDO/@V, 0, '=') or (iqtig:compare(felder/GERIKOMP/@V, 0, '=') and iqtig:compare(felder/ANFVOLLSTB/@V, 0, '=')) or iqtig:compare(felder/PHYSATEM/@V, 0, '=') or iqtig:compare(felder/SOPEINW/@V, 0, '=') or iqtig:compare(felder/SOPPERI/@V, 0, '=') or iqtig:compare(felder/SOPOPV/@V, 0, '=') or iqtig:compare(felder/SOPMED/@V, 0, '=') or iqtig:compare(felder/SOPBLUT/@V, 0, '=') or iqtig:compare(felder/SOPGERI/@V, 0, '=') or iqtig:compare(felder/SOPPHYS/@V, 0, '='))))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20718"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/GERIKOMP)}|{iqtig:feld(felder/FAKVERFPERS)}|{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/SOPOPV)}|{iqtig:feld(felder/APPAUSST)}|{iqtig:feld(felder/ANFVOLLSTA)}|{iqtig:feld(felder/APPAUSSTOP)}|{iqtig:feld(felder/INTENBETT)}|{iqtig:feld(felder/MINFAA)}|{iqtig:feld(felder/PHYSATEM)}|{iqtig:feld(felder/ANFVOLLSTB)}|{iqtig:feld(felder/ANLFA)}|{iqtig:feld(felder/SOPBLUT)}|{iqtig:feld(felder/FAORGEINHEIT)}|{iqtig:feld(felder/FAVERFUEGB)}|{iqtig:feld(felder/INTENBBEATM)}|{iqtig:feld(felder/OPABT)}|{iqtig:feld(felder/SOPEINW)}|{iqtig:feld(felder/BATSCHOCK)}|{iqtig:feld(felder/NOTFVERANT)}|{iqtig:feld(felder/ERFMIND)}|{iqtig:feld(felder/VERSORGPRAES)}|{iqtig:feld(felder/NOTFFORTB)}|{iqtig:feld(felder/MINFAIM)}|{iqtig:feld(felder/SOPGERI)}|{iqtig:feld(felder/SYSBEHAND)}|{iqtig:feld(felder/PERSINTENSIV)}|{iqtig:feld(felder/SOPPHYS)}|{iqtig:feld(felder/ERWSCHOCKT)}|{iqtig:feld(felder/SOPPERI)}|{iqtig:feld(felder/VERFUEGCT)}|{iqtig:feld(felder/SOPMED)}|{iqtig:feld(felder/AUSSENDO)}|{iqtig:feld(felder/STRUKTPROZ)}|{iqtig:feld(felder/NOTAUFN)}|{iqtig:feld(felder/AERZTLEIT)}|{iqtig:feld(felder/WEITERVERLUFT)}|{iqtig:feld(felder/SCHOCK)}"/>
					<error_message V="&quot;Erfüllung der Mindestanforderungen&#13;&#10;gemäß Checkliste&quot; ist &quot;ja&quot; [1], die Checkliste wurde aber nicht erfüllt"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ABMELD <> LEER) UND (ABMELD = 1 UND STICHTAG = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20723']))">
			<xsl:if test="(iqtig:compare(felder/ABMELD/@V, '', '!=') and (iqtig:compare(felder/ABMELD/@V, 1, '=') and iqtig:compare(felder/STICHTAG/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20723"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ABMELD)}|{iqtig:feld(felder/STICHTAG)}"/>
					<error_message V="&quot;Abmeldung vom Nachweisverfahren&quot; ist &quot;ja&quot; [1], obwohl &quot;Stichtag&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: @ARTNACHWEIS KEINSIN (1) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20726']))">
			<xsl:if test="(iqtig:KEINSIN(../C/felder/ARTNACHWEIS, (1)))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20726"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ARTNACHWEIS)}"/>
					<error_message V="Die Datenlieferung muss einen &quot;Erstmaliger Nachweis (Erstanmeldung)&quot; enthalten"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA <> LEER) UND (ANFTRAUMA = 1 UND STRUKTPROZ = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20734']))">
			<xsl:if test="(iqtig:compare(felder/ANFTRAUMA/@V, '', '!=') and (iqtig:compare(felder/ANFTRAUMA/@V, 1, '=') and iqtig:compare(felder/STRUKTPROZ/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20734"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/STRUKTPROZ)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist &quot;ja&quot; [1], obwohl &quot;A - Strukturen und Prozesse:&#13;&#10;Erfüllung aller 12 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA <> LEER) UND (ANFTRAUMA = 1 UND AERZTLEIT = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20735']))">
			<xsl:if test="(iqtig:compare(felder/ANFTRAUMA/@V, '', '!=') and (iqtig:compare(felder/ANFTRAUMA/@V, 1, '=') and iqtig:compare(felder/AERZTLEIT/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20735"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/AERZTLEIT)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist &quot;ja&quot; [1], obwohl &quot;B - Personal - Ärztliche Leitungsebene: &#13;&#10;Erfüllung aller 2 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA <> LEER) UND (ANFTRAUMA = 1 UND BATSCHOCK = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20736']))">
			<xsl:if test="(iqtig:compare(felder/ANFTRAUMA/@V, '', '!=') and (iqtig:compare(felder/ANFTRAUMA/@V, 1, '=') and iqtig:compare(felder/BATSCHOCK/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20736"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/BATSCHOCK)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist &quot;ja&quot; [1], obwohl &quot;B - Personal - Basisteam im Schockraum:&#13;&#10;Erfüllung aller 8 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA <> LEER) UND (ANFTRAUMA = 1 UND ERWSCHOCKT = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20737']))">
			<xsl:if test="(iqtig:compare(felder/ANFTRAUMA/@V, '', '!=') and (iqtig:compare(felder/ANFTRAUMA/@V, 1, '=') and iqtig:compare(felder/ERWSCHOCKT/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20737"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/ERWSCHOCKT)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist &quot;ja&quot; [1], obwohl &quot;B - Personal - Erweitertes Schockraumteam:&#13;&#10;Erfüllung aller 13 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA <> LEER) UND (ANFTRAUMA = 1 UND FAKVERFPERS = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20738']))">
			<xsl:if test="(iqtig:compare(felder/ANFTRAUMA/@V, '', '!=') and (iqtig:compare(felder/ANFTRAUMA/@V, 1, '=') and iqtig:compare(felder/FAKVERFPERS/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20738"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/FAKVERFPERS)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist &quot;ja&quot; [1], obwohl &quot;B - Personal - Fakultativ verfügbares Personal:&#13;&#10;Erfüllung aller 3 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA <> LEER) UND (ANFTRAUMA = 1 UND NOTAUFN = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20739']))">
			<xsl:if test="(iqtig:compare(felder/ANFTRAUMA/@V, '', '!=') and (iqtig:compare(felder/ANFTRAUMA/@V, 1, '=') and iqtig:compare(felder/NOTAUFN/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20739"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/NOTAUFN)}|{iqtig:feld(felder/ANFTRAUMA)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist &quot;ja&quot; [1], obwohl &quot;C - Räumliche Anforderungen - Notaufnahme:&#13;&#10;Erfüllung aller 8 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA <> LEER) UND (ANFTRAUMA = 1 UND OPABT = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20740']))">
			<xsl:if test="(iqtig:compare(felder/ANFTRAUMA/@V, '', '!=') and (iqtig:compare(felder/ANFTRAUMA/@V, 1, '=') and iqtig:compare(felder/OPABT/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20740"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/OPABT)}|{iqtig:feld(felder/ANFTRAUMA)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist &quot;ja&quot; [1], obwohl &quot;C - Räumliche Anforderungen - Operationsabteilung:&#13;&#10;Erfüllung der Mindestanforderung gemäß dem Anhang zu Anlage 3&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA <> LEER) UND (ANFTRAUMA = 1 UND PERSINTENSIV = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20741']))">
			<xsl:if test="(iqtig:compare(felder/ANFTRAUMA/@V, '', '!=') and (iqtig:compare(felder/ANFTRAUMA/@V, 1, '=') and iqtig:compare(felder/PERSINTENSIV/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20741"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/PERSINTENSIV)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist &quot;ja&quot; [1], obwohl &quot;D - Personelle Ausstattung der Intensivstation:&#13;&#10;Erfüllung aller 8 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA <> LEER) UND (ANFTRAUMA = 1 UND APPAUSST = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20742']))">
			<xsl:if test="(iqtig:compare(felder/ANFTRAUMA/@V, '', '!=') and (iqtig:compare(felder/ANFTRAUMA/@V, 1, '=') and iqtig:compare(felder/APPAUSST/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20742"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/APPAUSST)}|{iqtig:feld(felder/ANFTRAUMA)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist &quot;ja&quot; [1], obwohl &quot;E - Ausstattung/apparative Ausstattung:&#13;&#10;Erfüllung aller 18 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA <> LEER) UND (ANFTRAUMA = 1 UND APPAUSSTOP = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20743']))">
			<xsl:if test="(iqtig:compare(felder/ANFTRAUMA/@V, '', '!=') and (iqtig:compare(felder/ANFTRAUMA/@V, 1, '=') and iqtig:compare(felder/APPAUSSTOP/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20743"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/APPAUSSTOP)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist &quot;ja&quot; [1], obwohl &quot;E - Ausstattung/apparative Ausstattung:&#13;&#10;Erfüllung aller 3 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA <> LEER) UND (ANFTRAUMA = 0 UND MINFAA = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20744']))">
			<xsl:if test="(iqtig:compare(felder/ANFTRAUMA/@V, '', '!=') and (iqtig:compare(felder/ANFTRAUMA/@V, 0, '=') and iqtig:compare(felder/MINFAA/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20744"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/MINFAA)}|{iqtig:feld(felder/ANFTRAUMA)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist &quot;nein&quot; [0], obwohl &quot;Das Krankenhaus verfügt mindestens über die Fachabteilung Chirurgie oder&#13;&#10;Unfallchirurgie oder Allgemeine Chirurgie oder Orthopädie oder&#13;&#10;Orthopädie und Unfallchirurgie am Standort&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA <> LEER) UND (ANFTRAUMA = 0 UND MINFAIM = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20745']))">
			<xsl:if test="(iqtig:compare(felder/ANFTRAUMA/@V, '', '!=') and (iqtig:compare(felder/ANFTRAUMA/@V, 0, '=') and iqtig:compare(felder/MINFAIM/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20745"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/MINFAIM)}|{iqtig:feld(felder/ANFTRAUMA)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist &quot;nein&quot; [0], obwohl &quot;Das Krankenhaus verfügt mindestens über die Fachabteilung Innere Medizin am Standort&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA <> LEER) UND (ANFTRAUMA = 0 UND NOTFVERANT = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20746']))">
			<xsl:if test="(iqtig:compare(felder/ANFTRAUMA/@V, '', '!=') and (iqtig:compare(felder/ANFTRAUMA/@V, 0, '=') and iqtig:compare(felder/NOTFVERANT/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20746"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/NOTFVERANT)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist &quot;nein&quot; [0], obwohl &quot;Es sind jeweils ein für die Notfallversorgung verantwortlicher &#10;Arzt und eine Pflegekraft benannt, die fachlich und &#10;organisatorisch eindeutig der Versorgung von Notfällen zugeordnet und im Bedarfsfall verfügbar sind&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA <> LEER) UND (ANFTRAUMA = 0 UND FAVERFUEGB = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20747']))">
			<xsl:if test="(iqtig:compare(felder/ANFTRAUMA/@V, '', '!=') and (iqtig:compare(felder/ANFTRAUMA/@V, 0, '=') and iqtig:compare(felder/FAVERFUEGB/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20747"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/FAVERFUEGB)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist &quot;nein&quot; [0], obwohl &quot;Es ist jeweils ein Facharzt im Gebiet Innere Medizin,&#10;Chirurgie und Anästhesie innerhalb von maximal 30 Minuten am Patienten verfügbar&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA <> LEER) UND (ANFTRAUMA = 0 UND INTENBETT = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20748']))">
			<xsl:if test="(iqtig:compare(felder/ANFTRAUMA/@V, '', '!=') and (iqtig:compare(felder/ANFTRAUMA/@V, 0, '=') and iqtig:compare(felder/INTENBETT/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20748"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/INTENBETT)}|{iqtig:feld(felder/ANFTRAUMA)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist &quot;nein&quot; [0], obwohl &quot;Die Intensivstation verfügt über mindestens sechs Intensivtherapiebetten&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA <> LEER) UND (ANFTRAUMA = 0 UND INTENBBEATM = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20749']))">
			<xsl:if test="(iqtig:compare(felder/ANFTRAUMA/@V, '', '!=') and (iqtig:compare(felder/ANFTRAUMA/@V, 0, '=') and iqtig:compare(felder/INTENBBEATM/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20749"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/INTENBBEATM)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist &quot;nein&quot; [0], obwohl &quot;Mindestens drei Intensivtherapiebetten sind zur Versorgung &#10;beatmeter Patienten ausgestattet&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA <> LEER) UND (ANFTRAUMA = 0 UND SYSBEHAND = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20750']))">
			<xsl:if test="(iqtig:compare(felder/ANFTRAUMA/@V, '', '!=') and (iqtig:compare(felder/ANFTRAUMA/@V, 0, '=') and iqtig:compare(felder/SYSBEHAND/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20750"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/SYSBEHAND)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist &quot;nein&quot; [0], obwohl &quot;Es kommt ein strukturiertes und validiertes System zur Behandlungspriorisierung bei der Erstaufnahme von Notfallpatienten zur Anwendung&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA <> LEER) UND (ANFTRAUMA = 0 UND SCHOCK = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20751']))">
			<xsl:if test="(iqtig:compare(felder/ANFTRAUMA/@V, '', '!=') and (iqtig:compare(felder/ANFTRAUMA/@V, 0, '=') and iqtig:compare(felder/SCHOCK/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20751"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/SCHOCK)}|{iqtig:feld(felder/ANFTRAUMA)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist &quot;nein&quot; [0], obwohl &quot;Es ist ein Schockraum verfügbar&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA <> LEER) UND (ANFTRAUMA = 0 UND VERFUEGCT = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20752']))">
			<xsl:if test="(iqtig:compare(felder/ANFTRAUMA/@V, '', '!=') and (iqtig:compare(felder/ANFTRAUMA/@V, 0, '=') and iqtig:compare(felder/VERFUEGCT/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20752"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/VERFUEGCT)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist &quot;nein&quot; [0], obwohl &quot;Die 24-stündige Verfügbarkeit von Computertomographie ist sichergestellt&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANFTRAUMA <> LEER) UND (ANFTRAUMA = 0 UND WEITERVERLUFT = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20753']))">
			<xsl:if test="(iqtig:compare(felder/ANFTRAUMA/@V, '', '!=') and (iqtig:compare(felder/ANFTRAUMA/@V, 0, '=') and iqtig:compare(felder/WEITERVERLUFT/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20753"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/WEITERVERLUFT)}"/>
					<error_message V="&quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist &quot;nein&quot; [0], obwohl &quot;Es besteht die Möglichkeit der Weiterverlegung eines Notfallpatienten auf dem Luftweg in ein Krankenhaus der Basisnotfallversorgung oder einer höheren Stufe&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (AENDMELD <> LEER) UND (AENDMELD = 1 UND ANFTRAUMA = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20768']))">
			<xsl:if test="(iqtig:compare(felder/AENDMELD/@V, '', '!=') and (iqtig:compare(felder/AENDMELD/@V, 1, '=') and iqtig:compare(felder/ANFTRAUMA/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20768"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/ANFTRAUMA)}"/>
					<error_message V="&quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist &quot;ja&quot; [1], obwohl &quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (AENDMELD <> LEER) UND (AENDMELD = 1 UND FAORGEINHEIT = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20769']))">
			<xsl:if test="(iqtig:compare(felder/AENDMELD/@V, '', '!=') and (iqtig:compare(felder/AENDMELD/@V, 1, '=') and iqtig:compare(felder/FAORGEINHEIT/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20769"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/FAORGEINHEIT)}"/>
					<error_message V="&quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist &quot;ja&quot; [1], obwohl &quot;Die Versorgung der Patienten erfolgt in einer ärztlich geleiteten Fachabteilung, die eine fachlich unabhängige, abgrenzbare und organisatorisch eigenständige Organisationseinheit am Standort des Krankenhauses ist&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (AENDMELD <> LEER) UND (AENDMELD = 1 UND ANLFA = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20770']))">
			<xsl:if test="(iqtig:compare(felder/AENDMELD/@V, '', '!=') and (iqtig:compare(felder/AENDMELD/@V, 1, '=') and iqtig:compare(felder/ANLFA/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20770"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANLFA)}|{iqtig:feld(felder/AENDMELD)}"/>
					<error_message V="&quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist &quot;ja&quot; [1], obwohl &quot;Die Durchführung der mit den Kombinationen aus Diagnosen &#10;und Prozeduren nach Anlage 1 QSFFx-RL beschriebenen Operationen erfolgt &#10;durch oder unter Anleitung und Aufsicht einer Fachärztin oder eines Facharztes für Chirurgie&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (AENDMELD <> LEER) UND (AENDMELD = 1 UND VERSORGPRAES = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20771']))">
			<xsl:if test="(iqtig:compare(felder/AENDMELD/@V, '', '!=') and (iqtig:compare(felder/AENDMELD/@V, 1, '=') and iqtig:compare(felder/VERSORGPRAES/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20771"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/VERSORGPRAES)}"/>
					<error_message V="&quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist &quot;ja&quot; [1], obwohl &quot;Die ärztliche Versorgung in der Fachabteilung ist durch eine &#10;täglich 24 stündige Arztpräsenz im Krankenhaus (Bereitschaftsdienst möglich) sichergestellt, die auch eine jederzeitige operative Patientenversorgung gewährleistet&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (AENDMELD <> LEER) UND (AENDMELD = 1 UND AUSSENDO = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20772']))">
			<xsl:if test="(iqtig:compare(felder/AENDMELD/@V, '', '!=') and (iqtig:compare(felder/AENDMELD/@V, 1, '=') and iqtig:compare(felder/AUSSENDO/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20772"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/AUSSENDO)}"/>
					<error_message V="&quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist &quot;ja&quot; [1], obwohl &quot;Die Einrichtung und Ausstattung des Operationssaals lässt &#10;sowohl osteosynthetische als auch endoprothetische &#10;Versorgungen zu. Entsprechende Implantate und Instrumente stehen jederzeit zur Verfügung&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (AENDMELD <> LEER) UND (AENDMELD = 1 UND GERIKOMP = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20773']))">
			<xsl:if test="(iqtig:compare(felder/AENDMELD/@V, '', '!=') and (iqtig:compare(felder/AENDMELD/@V, 1, '=') and iqtig:compare(felder/GERIKOMP/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20773"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/GERIKOMP)}"/>
					<error_message V="&quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist &quot;ja&quot; [1], obwohl &quot;Für Patienten mit positivem geriatrischen Screening ist täglich &#10;geriatrische Kompetenz für die perioperative Versorgung gewährleistet&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (AENDMELD <> LEER) UND (AENDMELD = 1 UND PHYSATEM = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20774']))">
			<xsl:if test="(iqtig:compare(felder/AENDMELD/@V, '', '!=') and (iqtig:compare(felder/AENDMELD/@V, 1, '=') and iqtig:compare(felder/PHYSATEM/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20774"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/PHYSATEM)}"/>
					<error_message V="&quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist &quot;ja&quot; [1], obwohl &quot;Physiotherapie durch einen Physiotherapeuten/ eine &#10;Physiotherapeutin steht täglich für jeden Patienten zur &#10;Atemgymnastik und frühzeitigen Mobilisierung ab dem ersten postoperativen Tag zur Verfügung&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (AENDMELD <> LEER) UND (AENDMELD = 1 UND SOPEINW = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20775']))">
			<xsl:if test="(iqtig:compare(felder/AENDMELD/@V, '', '!=') and (iqtig:compare(felder/AENDMELD/@V, 1, '=') and iqtig:compare(felder/SOPEINW/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20775"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/SOPEINW)}|{iqtig:feld(felder/AENDMELD)}"/>
					<error_message V="&quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist &quot;ja&quot; [1], obwohl &quot;Der Krankenhausstandort verfügt über die SOP &quot;Besondere Situationen der Einwilligungsfähigkeit&quot;&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (AENDMELD <> LEER) UND (AENDMELD = 1 UND SOPPERI = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20776']))">
			<xsl:if test="(iqtig:compare(felder/AENDMELD/@V, '', '!=') and (iqtig:compare(felder/AENDMELD/@V, 1, '=') and iqtig:compare(felder/SOPPERI/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20776"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/SOPPERI)}|{iqtig:feld(felder/AENDMELD)}"/>
					<error_message V="&quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist &quot;ja&quot; [1], obwohl &quot;Der Krankenhausstandort verfügt über die SOP &quot;Perioperative &#10;Planung: Priorisierung von Eingriffen, Planung von OP Kapazitäten, Planung von OP-Teams&quot;&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (AENDMELD <> LEER) UND (AENDMELD = 1 UND SOPOPV = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20777']))">
			<xsl:if test="(iqtig:compare(felder/AENDMELD/@V, '', '!=') and (iqtig:compare(felder/AENDMELD/@V, 1, '=') and iqtig:compare(felder/SOPOPV/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20777"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/SOPOPV)}|{iqtig:feld(felder/AENDMELD)}"/>
					<error_message V="&quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist &quot;ja&quot; [1], obwohl &quot;Der Krankenhausstandort verfügt über die SOP &quot;Operationsverfahren&quot;&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (AENDMELD <> LEER) UND (AENDMELD = 1 UND SOPMED = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20778']))">
			<xsl:if test="(iqtig:compare(felder/AENDMELD/@V, '', '!=') and (iqtig:compare(felder/AENDMELD/@V, 1, '=') and iqtig:compare(felder/SOPMED/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20778"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/SOPMED)}|{iqtig:feld(felder/AENDMELD)}"/>
					<error_message V="&quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist &quot;ja&quot; [1], obwohl &quot;Der Krankenhausstandort verfügt über die SOP &quot;Umgang mit gerinnungshemmender Medikation&quot;&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (AENDMELD <> LEER) UND (AENDMELD = 1 UND SOPBLUT = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20779']))">
			<xsl:if test="(iqtig:compare(felder/AENDMELD/@V, '', '!=') and (iqtig:compare(felder/AENDMELD/@V, 1, '=') and iqtig:compare(felder/SOPBLUT/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20779"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/SOPBLUT)}|{iqtig:feld(felder/AENDMELD)}"/>
					<error_message V="&quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist &quot;ja&quot; [1], obwohl &quot;Der Krankenhausstandort verfügt über die SOP &quot;Patientenorientiertes Blutmanagement (PBM)&quot;&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (AENDMELD <> LEER) UND (AENDMELD = 1 UND SOPGERI = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20780']))">
			<xsl:if test="(iqtig:compare(felder/AENDMELD/@V, '', '!=') and (iqtig:compare(felder/AENDMELD/@V, 1, '=') and iqtig:compare(felder/SOPGERI/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20780"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/SOPGERI)}|{iqtig:feld(felder/AENDMELD)}"/>
					<error_message V="&quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist &quot;ja&quot; [1], obwohl &quot;Der Krankenhausstandort verfügt über die SOP &quot;Orthogeriatrische Zusammenarbeit für Patienten mit positivem geriatrischen Screening&quot;&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (AENDMELD <> LEER) UND (AENDMELD = 1 UND SOPPHYS = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20781']))">
			<xsl:if test="(iqtig:compare(felder/AENDMELD/@V, '', '!=') and (iqtig:compare(felder/AENDMELD/@V, 1, '=') and iqtig:compare(felder/SOPPHYS/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20781"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/SOPPHYS)}|{iqtig:feld(felder/AENDMELD)}"/>
					<error_message V="&quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist &quot;ja&quot; [1], obwohl &quot;Der Krankenhausstandort verfügt über die SOP &quot;Physiotherapeutische Maßnahmen&quot;&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (AENDMELD <> LEER UND STICHTAGAE <> LEER) UND (AENDMELD = 1 UND STICHTAGAE < '01.01.2024') -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20784']))">
			<xsl:if test="((iqtig:compare(felder/AENDMELD/@V, '', '!=') and iqtig:compare(felder/STICHTAGAE/@V, '', '!=')) and (iqtig:compare(felder/AENDMELD/@V, 1, '=') and iqtig:compare(felder/STICHTAGAE/@V, '01.01.2024', '&lt;')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20784"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/STICHTAGAE)}"/>
					<error_message V="&quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist &quot;ja&quot; [1] und &quot;Datum des Eintretens der Nichterfüllung bzw. der Wiedererfüllung&quot; ist kleiner als 01.01.2024"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (AENDMELD <> LEER UND STICHTAGAE <> LEER) UND (AENDMELD = 1 UND STICHTAGAE > '31.12.2024') -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20785']))">
			<xsl:if test="((iqtig:compare(felder/AENDMELD/@V, '', '!=') and iqtig:compare(felder/STICHTAGAE/@V, '', '!=')) and (iqtig:compare(felder/AENDMELD/@V, 1, '=') and iqtig:compare(felder/STICHTAGAE/@V, '31.12.2024', '&gt;')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20785"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/STICHTAGAE)}"/>
					<error_message V="&quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist &quot;ja&quot; [1] und &quot;Datum des Eintretens der Nichterfüllung bzw. der Wiedererfüllung&quot; ist größer als 31.12.2024"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ <> LEER) UND (ANMELDEJ = 1 UND ERFMIND = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20808']))">
			<xsl:if test="(iqtig:compare(felder/ANMELDEJ/@V, '', '!=') and (iqtig:compare(felder/ANMELDEJ/@V, 1, '=') and iqtig:compare(felder/ERFMIND/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20808"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ERFMIND)}|{iqtig:feld(felder/ANMELDEJ)}"/>
					<error_message V="&quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; ist &quot;ja&quot; [1], obwohl &quot;Erfüllung der Mindestanforderungen gemäß Checkliste&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (AENDMELD <> LEER) UND (AENDMELD = 1 UND ERFMIND = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20810']))">
			<xsl:if test="(iqtig:compare(felder/AENDMELD/@V, '', '!=') and (iqtig:compare(felder/AENDMELD/@V, 1, '=') and iqtig:compare(felder/ERFMIND/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20810"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ERFMIND)}|{iqtig:feld(felder/AENDMELD)}"/>
					<error_message V="&quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist &quot;ja&quot; [1], obwohl &quot;Erfüllung der Mindestanforderungen gemäß Checkliste&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: AENDMELD = LEER UND ANMELDEJ = LEER UND ABMELD = LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20829']))">
			<xsl:if test="(iqtig:compare(felder/AENDMELD/@V, '', '=') and iqtig:compare(felder/ANMELDEJ/@V, '', '=') and iqtig:compare(felder/ABMELD/@V, '', '='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20829"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANMELDEJ)}|{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/ABMELD)}"/>
					<error_message V="Keines der Felder &quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot;, &quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; und &quot;Abmeldung vom Nachweisverfahren&quot; ist ausgefüllt"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ = LEER ODER ANMELDEJ <> 1) UND (ABMELD = LEER ODER ABMELD <> 1) UND STICHTAG <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20830']))">
			<xsl:if test="((iqtig:compare(felder/ANMELDEJ/@V, '', '=') or iqtig:compare(felder/ANMELDEJ/@V, 1, '!=')) and (iqtig:compare(felder/ABMELD/@V, '', '=') or iqtig:compare(felder/ABMELD/@V, 1, '!=')) and iqtig:compare(felder/STICHTAG/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20830"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANMELDEJ)}|{iqtig:feld(felder/STICHTAG)}|{iqtig:feld(felder/ABMELD)}"/>
					<error_message V="Jedes der Felder &quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; und &quot;Abmeldung vom Nachweisverfahren&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;Stichtag&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ = LEER ODER ANMELDEJ <> 1) UND (AENDMELD = LEER ODER AENDMELD <> 1) UND ANFTRAUMA <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20833']))">
			<xsl:if test="((iqtig:compare(felder/ANMELDEJ/@V, '', '=') or iqtig:compare(felder/ANMELDEJ/@V, 1, '!=')) and (iqtig:compare(felder/AENDMELD/@V, '', '=') or iqtig:compare(felder/AENDMELD/@V, 1, '!=')) and iqtig:compare(felder/ANFTRAUMA/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20833"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/ANFTRAUMA)}|{iqtig:feld(felder/ANMELDEJ)}"/>
					<error_message V="Jedes der Felder &quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; und &quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ = LEER ODER ANMELDEJ <> 1) UND (AENDMELD = LEER ODER AENDMELD <> 1) UND FAORGEINHEIT <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20834']))">
			<xsl:if test="((iqtig:compare(felder/ANMELDEJ/@V, '', '=') or iqtig:compare(felder/ANMELDEJ/@V, 1, '!=')) and (iqtig:compare(felder/AENDMELD/@V, '', '=') or iqtig:compare(felder/AENDMELD/@V, 1, '!=')) and iqtig:compare(felder/FAORGEINHEIT/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20834"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/FAORGEINHEIT)}|{iqtig:feld(felder/ANMELDEJ)}"/>
					<error_message V="Jedes der Felder &quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; und &quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;Die Versorgung der Patienten erfolgt in einer ärztlich geleiteten Fachabteilung, die eine fachlich unabhängige, abgrenzbare und organisatorisch eigenständige Organisationseinheit am Standort des Krankenhauses ist&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ = LEER ODER ANMELDEJ <> 1) UND (AENDMELD = LEER ODER AENDMELD <> 1) UND ANLFA <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20835']))">
			<xsl:if test="((iqtig:compare(felder/ANMELDEJ/@V, '', '=') or iqtig:compare(felder/ANMELDEJ/@V, 1, '!=')) and (iqtig:compare(felder/AENDMELD/@V, '', '=') or iqtig:compare(felder/AENDMELD/@V, 1, '!=')) and iqtig:compare(felder/ANLFA/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20835"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANMELDEJ)}|{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/ANLFA)}"/>
					<error_message V="Jedes der Felder &quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; und &quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;Die Durchführung der mit den Kombinationen aus Diagnosen &#10;und Prozeduren nach Anlage 1 QSFFx-RL beschriebenen Operationen erfolgt &#10;durch oder unter Anleitung und Aufsicht einer Fachärztin oder eines Facharztes für Chirurgie&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ = LEER ODER ANMELDEJ <> 1) UND (AENDMELD = LEER ODER AENDMELD <> 1) UND VERSORGPRAES <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20836']))">
			<xsl:if test="((iqtig:compare(felder/ANMELDEJ/@V, '', '=') or iqtig:compare(felder/ANMELDEJ/@V, 1, '!=')) and (iqtig:compare(felder/AENDMELD/@V, '', '=') or iqtig:compare(felder/AENDMELD/@V, 1, '!=')) and iqtig:compare(felder/VERSORGPRAES/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20836"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/VERSORGPRAES)}|{iqtig:feld(felder/ANMELDEJ)}"/>
					<error_message V="Jedes der Felder &quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; und &quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;Die ärztliche Versorgung in der Fachabteilung ist durch eine &#10;täglich 24 stündige Arztpräsenz im Krankenhaus (Bereitschaftsdienst möglich) sichergestellt, die auch eine jederzeitige operative Patientenversorgung gewährleistet&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ = LEER ODER ANMELDEJ <> 1) UND (AENDMELD = LEER ODER AENDMELD <> 1) UND AUSSENDO <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20837']))">
			<xsl:if test="((iqtig:compare(felder/ANMELDEJ/@V, '', '=') or iqtig:compare(felder/ANMELDEJ/@V, 1, '!=')) and (iqtig:compare(felder/AENDMELD/@V, '', '=') or iqtig:compare(felder/AENDMELD/@V, 1, '!=')) and iqtig:compare(felder/AUSSENDO/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20837"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/AUSSENDO)}|{iqtig:feld(felder/ANMELDEJ)}"/>
					<error_message V="Jedes der Felder &quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; und &quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;Die Einrichtung und Ausstattung des Operationssaals lässt &#10;sowohl osteosynthetische als auch endoprothetische &#10;Versorgungen zu. Entsprechende Implantate und Instrumente stehen jederzeit zur Verfügung&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ = LEER ODER ANMELDEJ <> 1) UND (AENDMELD = LEER ODER AENDMELD <> 1) UND GERIKOMP <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20838']))">
			<xsl:if test="((iqtig:compare(felder/ANMELDEJ/@V, '', '=') or iqtig:compare(felder/ANMELDEJ/@V, 1, '!=')) and (iqtig:compare(felder/AENDMELD/@V, '', '=') or iqtig:compare(felder/AENDMELD/@V, 1, '!=')) and iqtig:compare(felder/GERIKOMP/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20838"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/GERIKOMP)}|{iqtig:feld(felder/ANMELDEJ)}"/>
					<error_message V="Jedes der Felder &quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; und &quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;Für Patienten mit positivem geriatrischen Screening ist täglich &#10;geriatrische Kompetenz für die perioperative Versorgung gewährleistet&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ = LEER ODER ANMELDEJ <> 1) UND (AENDMELD = LEER ODER AENDMELD <> 1) UND PHYSATEM <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20839']))">
			<xsl:if test="((iqtig:compare(felder/ANMELDEJ/@V, '', '=') or iqtig:compare(felder/ANMELDEJ/@V, 1, '!=')) and (iqtig:compare(felder/AENDMELD/@V, '', '=') or iqtig:compare(felder/AENDMELD/@V, 1, '!=')) and iqtig:compare(felder/PHYSATEM/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20839"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/PHYSATEM)}|{iqtig:feld(felder/ANMELDEJ)}"/>
					<error_message V="Jedes der Felder &quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; und &quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;Physiotherapie durch einen Physiotherapeuten/ eine &#10;Physiotherapeutin steht täglich für jeden Patienten zur &#10;Atemgymnastik und frühzeitigen Mobilisierung ab dem ersten postoperativen Tag zur Verfügung&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ = LEER ODER ANMELDEJ <> 1) UND (AENDMELD = LEER ODER AENDMELD <> 1) UND SOPEINW <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20840']))">
			<xsl:if test="((iqtig:compare(felder/ANMELDEJ/@V, '', '=') or iqtig:compare(felder/ANMELDEJ/@V, 1, '!=')) and (iqtig:compare(felder/AENDMELD/@V, '', '=') or iqtig:compare(felder/AENDMELD/@V, 1, '!=')) and iqtig:compare(felder/SOPEINW/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20840"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANMELDEJ)}|{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/SOPEINW)}"/>
					<error_message V="Jedes der Felder &quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; und &quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;Der Krankenhausstandort verfügt über die SOP &quot;Besondere Situationen der Einwilligungsfähigkeit&quot;&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ = LEER ODER ANMELDEJ <> 1) UND (AENDMELD = LEER ODER AENDMELD <> 1) UND SOPPERI <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20841']))">
			<xsl:if test="((iqtig:compare(felder/ANMELDEJ/@V, '', '=') or iqtig:compare(felder/ANMELDEJ/@V, 1, '!=')) and (iqtig:compare(felder/AENDMELD/@V, '', '=') or iqtig:compare(felder/AENDMELD/@V, 1, '!=')) and iqtig:compare(felder/SOPPERI/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20841"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANMELDEJ)}|{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/SOPPERI)}"/>
					<error_message V="Jedes der Felder &quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; und &quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;Der Krankenhausstandort verfügt über die SOP &quot;Perioperative &#10;Planung: Priorisierung von Eingriffen, Planung von OP Kapazitäten, Planung von OP-Teams&quot;&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ = LEER ODER ANMELDEJ <> 1) UND (AENDMELD = LEER ODER AENDMELD <> 1) UND SOPOPV <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20842']))">
			<xsl:if test="((iqtig:compare(felder/ANMELDEJ/@V, '', '=') or iqtig:compare(felder/ANMELDEJ/@V, 1, '!=')) and (iqtig:compare(felder/AENDMELD/@V, '', '=') or iqtig:compare(felder/AENDMELD/@V, 1, '!=')) and iqtig:compare(felder/SOPOPV/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20842"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANMELDEJ)}|{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/SOPOPV)}"/>
					<error_message V="Jedes der Felder &quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; und &quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;Der Krankenhausstandort verfügt über die SOP &quot;Operationsverfahren&quot;&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ = LEER ODER ANMELDEJ <> 1) UND (AENDMELD = LEER ODER AENDMELD <> 1) UND SOPMED <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20843']))">
			<xsl:if test="((iqtig:compare(felder/ANMELDEJ/@V, '', '=') or iqtig:compare(felder/ANMELDEJ/@V, 1, '!=')) and (iqtig:compare(felder/AENDMELD/@V, '', '=') or iqtig:compare(felder/AENDMELD/@V, 1, '!=')) and iqtig:compare(felder/SOPMED/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20843"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANMELDEJ)}|{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/SOPMED)}"/>
					<error_message V="Jedes der Felder &quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; und &quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;Der Krankenhausstandort verfügt über die SOP &quot;Umgang mit gerinnungshemmender Medikation&quot;&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ = LEER ODER ANMELDEJ <> 1) UND (AENDMELD = LEER ODER AENDMELD <> 1) UND SOPBLUT <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20844']))">
			<xsl:if test="((iqtig:compare(felder/ANMELDEJ/@V, '', '=') or iqtig:compare(felder/ANMELDEJ/@V, 1, '!=')) and (iqtig:compare(felder/AENDMELD/@V, '', '=') or iqtig:compare(felder/AENDMELD/@V, 1, '!=')) and iqtig:compare(felder/SOPBLUT/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20844"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANMELDEJ)}|{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/SOPBLUT)}"/>
					<error_message V="Jedes der Felder &quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; und &quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;Der Krankenhausstandort verfügt über die SOP &quot;Patientenorientiertes Blutmanagement (PBM)&quot;&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ = LEER ODER ANMELDEJ <> 1) UND (AENDMELD = LEER ODER AENDMELD <> 1) UND SOPGERI <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20845']))">
			<xsl:if test="((iqtig:compare(felder/ANMELDEJ/@V, '', '=') or iqtig:compare(felder/ANMELDEJ/@V, 1, '!=')) and (iqtig:compare(felder/AENDMELD/@V, '', '=') or iqtig:compare(felder/AENDMELD/@V, 1, '!=')) and iqtig:compare(felder/SOPGERI/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20845"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANMELDEJ)}|{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/SOPGERI)}"/>
					<error_message V="Jedes der Felder &quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; und &quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;Der Krankenhausstandort verfügt über die SOP &quot;Orthogeriatrische Zusammenarbeit für Patienten mit positivem geriatrischen Screening&quot;&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ = LEER ODER ANMELDEJ <> 1) UND (AENDMELD = LEER ODER AENDMELD <> 1) UND SOPPHYS <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20846']))">
			<xsl:if test="((iqtig:compare(felder/ANMELDEJ/@V, '', '=') or iqtig:compare(felder/ANMELDEJ/@V, 1, '!=')) and (iqtig:compare(felder/AENDMELD/@V, '', '=') or iqtig:compare(felder/AENDMELD/@V, 1, '!=')) and iqtig:compare(felder/SOPPHYS/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20846"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANMELDEJ)}|{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/SOPPHYS)}"/>
					<error_message V="Jedes der Felder &quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; und &quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;Der Krankenhausstandort verfügt über die SOP &quot;Physiotherapeutische Maßnahmen&quot;&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ = LEER ODER ANMELDEJ <> 1) UND (AENDMELD = LEER ODER AENDMELD <> 1) UND ERFMIND <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20847']))">
			<xsl:if test="((iqtig:compare(felder/ANMELDEJ/@V, '', '=') or iqtig:compare(felder/ANMELDEJ/@V, 1, '!=')) and (iqtig:compare(felder/AENDMELD/@V, '', '=') or iqtig:compare(felder/AENDMELD/@V, 1, '!=')) and iqtig:compare(felder/ERFMIND/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20847"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANMELDEJ)}|{iqtig:feld(felder/AENDMELD)}|{iqtig:feld(felder/ERFMIND)}"/>
					<error_message V="Jedes der Felder &quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; und &quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;Erfüllung der Mindestanforderungen gemäß Checkliste&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ <> LEER) UND (ANMELDEJ = 1 UND ARTNACHWEIS = LEER) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20849']))">
			<xsl:if test="(iqtig:compare(felder/ANMELDEJ/@V, '', '!=') and (iqtig:compare(felder/ANMELDEJ/@V, 1, '=') and iqtig:compare(felder/ARTNACHWEIS/@V, '', '=')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20849"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANMELDEJ)}|{iqtig:feld(felder/ARTNACHWEIS)}"/>
					<error_message V="&quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; ist &quot;ja&quot; [1], obwohl &quot;Art des Nachweis&quot; nicht ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ANMELDEJ = LEER ODER ANMELDEJ <> 1) UND ARTNACHWEIS <> LEER -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20850']))">
			<xsl:if test="((iqtig:compare(felder/ANMELDEJ/@V, '', '=') or iqtig:compare(felder/ANMELDEJ/@V, 1, '!=')) and iqtig:compare(felder/ARTNACHWEIS/@V, '', '!='))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20850"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ANMELDEJ)}|{iqtig:feld(felder/ARTNACHWEIS)}"/>
					<error_message V="&quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; ist nicht &quot;ja&quot; [1], obwohl &quot;Art des Nachweis&quot; ausgefüllt ist"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (STICHTAG <> LEER) UND (ARTNACHWEIS IN (1;3) UND STICHTAG < '15.11.2023') -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20853']))">
			<xsl:if test="(iqtig:compare(felder/STICHTAG/@V, '', '!=') and ((iqtig:IN(felder/ARTNACHWEIS, (1,3))) and iqtig:compare(felder/STICHTAG/@V, '15.11.2023', '&lt;')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20853"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/STICHTAG)}|{iqtig:feld(felder/ARTNACHWEIS)}"/>
					<error_message V="&quot;Art des Nachweis&quot; ist &quot;Erstmaliger Nachweis (Erstanmeldung)&quot; [1] oder &quot;Erneuter Nachweis nach Abmeldung vom Nachweisverfahren (Wiederanmeldung)&quot; [3] und &quot;Stichtag&quot; ist kleiner als 15.11.2023"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (STICHTAG <> LEER) UND (ARTNACHWEIS IN (1;3) UND STICHTAG > '31.12.2024') -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20854']))">
			<xsl:if test="(iqtig:compare(felder/STICHTAG/@V, '', '!=') and ((iqtig:IN(felder/ARTNACHWEIS, (1,3))) and iqtig:compare(felder/STICHTAG/@V, '31.12.2024', '&gt;')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20854"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/STICHTAG)}|{iqtig:feld(felder/ARTNACHWEIS)}"/>
					<error_message V="&quot;Art des Nachweis&quot; ist &quot;Erstmaliger Nachweis (Erstanmeldung)&quot; [1] oder &quot;Erneuter Nachweis nach Abmeldung vom Nachweisverfahren (Wiederanmeldung)&quot; [3] und &quot;Stichtag&quot; ist größer als 31.12.2024"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ERFMIND <> LEER) UND (ERFMIND = 0 UND ARTNACHWEIS IN (1;3)) -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20855']))">
			<xsl:if test="(iqtig:compare(felder/ERFMIND/@V, '', '!=') and (iqtig:compare(felder/ERFMIND/@V, 0, '=') and (iqtig:IN(felder/ARTNACHWEIS, (1,3)))))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20855"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ERFMIND)}|{iqtig:feld(felder/ARTNACHWEIS)}"/>
					<error_message V="&quot;Erfüllung der Mindestanforderungen gemäß Checkliste&quot; ist &quot;nein&quot; [0] und &quot;Art des Nachweis&quot; ist &quot;Erstmaliger Nachweis (Erstanmeldung)&quot; [1] oder &quot;Erneuter Nachweis nach Abmeldung vom Nachweisverfahren (Wiederanmeldung)&quot; [3]"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ARTNACHWEIS <> LEER UND STICHTAG <> LEER) UND (ARTNACHWEIS = 2 UND STICHTAG < '15.11.2024') -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20856']))">
			<xsl:if test="((iqtig:compare(felder/ARTNACHWEIS/@V, '', '!=') and iqtig:compare(felder/STICHTAG/@V, '', '!=')) and (iqtig:compare(felder/ARTNACHWEIS/@V, 2, '=') and iqtig:compare(felder/STICHTAG/@V, '15.11.2024', '&lt;')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20856"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/STICHTAG)}|{iqtig:feld(felder/ARTNACHWEIS)}"/>
					<error_message V="&quot;Art des Nachweis&quot; ist &quot;Jährlicher Nachweis nach § 6 Abs. 1 Satz 1 (Statusmeldung)&quot; [2] und &quot;Stichtag&quot; ist kleiner als 15.11.2024"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ARTNACHWEIS <> LEER UND STICHTAG <> LEER) UND (ARTNACHWEIS = 2 UND STICHTAG > '31.12.2024') -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20857']))">
			<xsl:if test="((iqtig:compare(felder/ARTNACHWEIS/@V, '', '!=') and iqtig:compare(felder/STICHTAG/@V, '', '!=')) and (iqtig:compare(felder/ARTNACHWEIS/@V, 2, '=') and iqtig:compare(felder/STICHTAG/@V, '31.12.2024', '&gt;')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20857"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/STICHTAG)}|{iqtig:feld(felder/ARTNACHWEIS)}"/>
					<error_message V="&quot;Art des Nachweis&quot; ist &quot;Jährlicher Nachweis nach § 6 Abs. 1 Satz 1 (Statusmeldung)&quot; [2] und &quot;Stichtag&quot; ist größer als 31.12.2024"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ABMELD <> LEER UND STICHTAG <> LEER) UND (ABMELD = 1 UND STICHTAG < '15.11.2023') -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20858']))">
			<xsl:if test="((iqtig:compare(felder/ABMELD/@V, '', '!=') and iqtig:compare(felder/STICHTAG/@V, '', '!=')) and (iqtig:compare(felder/ABMELD/@V, 1, '=') and iqtig:compare(felder/STICHTAG/@V, '15.11.2023', '&lt;')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20858"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ABMELD)}|{iqtig:feld(felder/STICHTAG)}"/>
					<error_message V="&quot;Abmeldung vom Nachweisverfahren&quot; ist &quot;ja&quot; [1] und &quot;Stichtag&quot; ist kleiner als 15.11.2023"/>
				</error>
			</xsl:if>
		</xsl:if>
		<!-- FFX:C: (ABMELD <> LEER UND STICHTAG <> LEER) UND (ABMELD = 1 UND STICHTAG > '31.12.2024') -->
		<xsl:if test="not(exists($blacklist_ids[text() = '20859']))">
			<xsl:if test="((iqtig:compare(felder/ABMELD/@V, '', '!=') and iqtig:compare(felder/STICHTAG/@V, '', '!=')) and (iqtig:compare(felder/ABMELD/@V, 1, '=') and iqtig:compare(felder/STICHTAG/@V, '31.12.2024', '&gt;')))">
				<error>
					<error_type V="REGEL"/>
					<rule_id V="20859"/>
					<rule_type V="H"/>
					<list V="{iqtig:feld(felder/ABMELD)}|{iqtig:feld(felder/STICHTAG)}"/>
					<error_message V="&quot;Abmeldung vom Nachweisverfahren&quot; ist &quot;ja&quot; [1] und &quot;Stichtag&quot; ist größer als 31.12.2024"/>
				</error>
			</xsl:if>
		</xsl:if>
	</xsl:template>
	<xsl:template match="C" mode="formsFFX">
		<xsl:variable name="this" select="."/>
		<xsl:if test="exists(preceding-sibling::C[felder/LFDCHL/@V = $this/felder/LFDCHL/@V])">
			<error>
				<error_type V="TDS"/>
				<rule_id V="1001045"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(felder/LFDCHL)}"/>
				<error_message V="Die ID LFDCHL des Kindbogens ist bezogen auf den Mutterbogen nicht eindeutig."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="DokAbschlDat" mode="valuesFFX">
		<!-- does not match (0[1-9]|[12][0-9]|3[01])[\.](0[1-9]|1[012])[\.](19|20)\d{2} -->
		<xsl:if test="iqtig:exists(@V) and not(matches(@V, '^(0[1-9]|[12][0-9]|3[01])[\.](0[1-9]|1[012])[\.](19|20)\d{2}$'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001018"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:B:DokAbschlDat entspricht nicht der vorgegebenen Formatanweisung &quot;(0[1-9]|[12][0-9]|3[01])[\.](0[1-9]|1[012])[\.](19|20)\d&amp;#123;2&amp;#125;&quot;."/>
			</error>
		</xsl:if>
		<!-- not filled out -->
		<xsl:if test="not(iqtig:exists(@V)) and not(exists(preceding-sibling::DokAbschlDat))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001022"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Das Datenfeld FFX:B:DokAbschlDat muss einen gültigen Wert enthalten."/>
			</error>
		</xsl:if>
		<!-- length(DokAbschlDat) > 10 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 10">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:B:DokAbschlDat überschreitet die zulässige Feldlänge 10."/>
			</error>
		</xsl:if>
		<!-- DokAbschlDat not a valid date -->
		<xsl:if test="iqtig:exists(@V) and not(iqtig:date_string(@V) castable as xs:date)">
			<error>
				<error_type V="WERT"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:B:DokAbschlDat ist kein gültiges Datum."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="NAMEKH" mode="valuesFFX">
		<!-- not filled out -->
		<xsl:if test="not(iqtig:exists(@V)) and not(exists(preceding-sibling::NAMEKH))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001022"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Das Datenfeld FFX:B:NAMEKH &quot;Name der Einrichtung&quot; muss einen gültigen Wert enthalten."/>
			</error>
		</xsl:if>
		<!-- length(NAMEKH) > 100 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 100">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:B:NAMEKH &quot;Name der Einrichtung&quot; überschreitet die zulässige Feldlänge 100."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="AUSSENDO" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20585</id>
				<id>20718</id>
				<id>20772</id>
				<id>20837</id>
			</blacklist>
		</xsl:variable>
		<!-- AUSSENDO not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:AUSSENDO &quot;Die Einrichtung und Ausstattung des Operationssaals lässt &#10;sowohl osteosynthetische als auch endoprothetische &#10;Versorgungen zu. Entsprechende Implantate und Instrumente stehen jederzeit zur Verfügung&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(AUSSENDO) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:AUSSENDO &quot;Die Einrichtung und Ausstattung des Operationssaals lässt &#10;sowohl osteosynthetische als auch endoprothetische &#10;Versorgungen zu. Entsprechende Implantate und Instrumente stehen jederzeit zur Verfügung&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SOPMED" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20591</id>
				<id>20718</id>
				<id>20778</id>
				<id>20843</id>
			</blacklist>
		</xsl:variable>
		<!-- SOPMED not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SOPMED &quot;Der Krankenhausstandort verfügt über die SOP &quot;Umgang mit gerinnungshemmender Medikation&quot;&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(SOPMED) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SOPMED &quot;Der Krankenhausstandort verfügt über die SOP &quot;Umgang mit gerinnungshemmender Medikation&quot;&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="BATSCHOCK" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20457</id>
				<id>20718</id>
				<id>20736</id>
			</blacklist>
		</xsl:variable>
		<!-- BATSCHOCK not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:BATSCHOCK &quot;B - Personal - Basisteam im Schockraum:&#13;&#10;Erfüllung aller 8 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(BATSCHOCK) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:BATSCHOCK &quot;B - Personal - Basisteam im Schockraum:&#13;&#10;Erfüllung aller 8 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SCHOCK" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20476</id>
				<id>20718</id>
				<id>20751</id>
			</blacklist>
		</xsl:variable>
		<!-- SCHOCK not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SCHOCK &quot;Es ist ein Schockraum verfügbar&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(SCHOCK) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SCHOCK &quot;Es ist ein Schockraum verfügbar&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="APPAUSSTOP" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20465</id>
				<id>20718</id>
				<id>20743</id>
			</blacklist>
		</xsl:variable>
		<!-- APPAUSSTOP not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:APPAUSSTOP &quot;E - Ausstattung/apparative Ausstattung:&#13;&#10;Erfüllung aller 3 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(APPAUSSTOP) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:APPAUSSTOP &quot;E - Ausstattung/apparative Ausstattung:&#13;&#10;Erfüllung aller 3 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="NOTFVERANTFG" mode="valuesFFX">
		<!-- length(NOTFVERANTFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:NOTFVERANTFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SOPBLUT" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20592</id>
				<id>20718</id>
				<id>20779</id>
				<id>20844</id>
			</blacklist>
		</xsl:variable>
		<!-- SOPBLUT not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SOPBLUT &quot;Der Krankenhausstandort verfügt über die SOP &quot;Patientenorientiertes Blutmanagement (PBM)&quot;&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(SOPBLUT) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SOPBLUT &quot;Der Krankenhausstandort verfügt über die SOP &quot;Patientenorientiertes Blutmanagement (PBM)&quot;&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="NOTFFORTB" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20642</id>
				<id>20645</id>
				<id>20718</id>
			</blacklist>
		</xsl:variable>
		<!-- NOTFFORTB not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:NOTFFORTB &quot;Der für die Notfallversorgung benannte Arzt und die für die Notfallversorgung benannte Pflegekraft nehmen regelmäßig an &#10;fachspezifischen Fortbildungen für Notfallmedizin teil&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(NOTFFORTB) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:NOTFFORTB &quot;Der für die Notfallversorgung benannte Arzt und die für die Notfallversorgung benannte Pflegekraft nehmen regelmäßig an &#10;fachspezifischen Fortbildungen für Notfallmedizin teil&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="STICHTAGAE" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>19820</id>
				<id>19822</id>
				<id>20784</id>
				<id>20785</id>
			</blacklist>
		</xsl:variable>
		<!-- does not match (0[1-9]|[12][0-9]|3[01])[\.](0[1-9]|1[012])[\.](19|20)\d{2} -->
		<xsl:if test="iqtig:exists(@V) and not(matches(@V, '^(0[1-9]|[12][0-9]|3[01])[\.](0[1-9]|1[012])[\.](19|20)\d{2}$'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001018"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:STICHTAGAE &quot;Datum des Eintretens der Nichterfüllung bzw. der Wiedererfüllung&quot; entspricht nicht der vorgegebenen Formatanweisung &quot;(0[1-9]|[12][0-9]|3[01])[\.](0[1-9]|1[012])[\.](19|20)\d&amp;#123;2&amp;#125;&quot;."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(STICHTAGAE) > 10 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 10">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:STICHTAGAE &quot;Datum des Eintretens der Nichterfüllung bzw. der Wiedererfüllung&quot; überschreitet die zulässige Feldlänge 10."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- STICHTAGAE not a valid date -->
		<xsl:if test="iqtig:exists(@V) and not(iqtig:date_string(@V) castable as xs:date)">
			<error>
				<error_type V="WERT"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:STICHTAGAE &quot;Datum des Eintretens der Nichterfüllung bzw. der Wiedererfüllung&quot; ist kein gültiges Datum."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="GERIKOMP" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>19810</id>
				<id>19878</id>
				<id>20586</id>
				<id>20718</id>
				<id>20773</id>
				<id>20838</id>
			</blacklist>
		</xsl:variable>
		<!-- GERIKOMP not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:GERIKOMP &quot;Für Patienten mit positivem geriatrischen Screening ist täglich &#10;geriatrische Kompetenz für die perioperative Versorgung gewährleistet&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(GERIKOMP) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:GERIKOMP &quot;Für Patienten mit positivem geriatrischen Screening ist täglich &#10;geriatrische Kompetenz für die perioperative Versorgung gewährleistet&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="NOTFPWEITERBFG" mode="valuesFFX">
		<!-- length(NOTFPWEITERBFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:NOTFPWEITERBFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SOPEINW" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20588</id>
				<id>20718</id>
				<id>20775</id>
				<id>20840</id>
			</blacklist>
		</xsl:variable>
		<!-- SOPEINW not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SOPEINW &quot;Der Krankenhausstandort verfügt über die SOP &quot;Besondere Situationen der Einwilligungsfähigkeit&quot;&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(SOPEINW) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SOPEINW &quot;Der Krankenhausstandort verfügt über die SOP &quot;Besondere Situationen der Einwilligungsfähigkeit&quot;&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SYSBEHAND" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20475</id>
				<id>20718</id>
				<id>20750</id>
			</blacklist>
		</xsl:variable>
		<!-- SYSBEHAND not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SYSBEHAND &quot;Es kommt ein strukturiertes und validiertes System zur Behandlungspriorisierung bei der Erstaufnahme von Notfallpatienten zur Anwendung&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(SYSBEHAND) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SYSBEHAND &quot;Es kommt ein strukturiertes und validiertes System zur Behandlungspriorisierung bei der Erstaufnahme von Notfallpatienten zur Anwendung&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="PERSINTENSIVFG" mode="valuesFFX">
		<!-- length(PERSINTENSIVFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:PERSINTENSIVFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="OPABTFG" mode="valuesFFX">
		<!-- length(OPABTFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:OPABTFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="APPAUSST" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20464</id>
				<id>20718</id>
				<id>20742</id>
			</blacklist>
		</xsl:variable>
		<!-- APPAUSST not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:APPAUSST &quot;E - Ausstattung/apparative Ausstattung:&#13;&#10;Erfüllung aller 18 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(APPAUSST) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:APPAUSST &quot;E - Ausstattung/apparative Ausstattung:&#13;&#10;Erfüllung aller 18 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SOPOPV" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20590</id>
				<id>20718</id>
				<id>20777</id>
				<id>20842</id>
			</blacklist>
		</xsl:variable>
		<!-- SOPOPV not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SOPOPV &quot;Der Krankenhausstandort verfügt über die SOP &quot;Operationsverfahren&quot;&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(SOPOPV) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SOPOPV &quot;Der Krankenhausstandort verfügt über die SOP &quot;Operationsverfahren&quot;&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="ERWSCHOCKTFG" mode="valuesFFX">
		<!-- length(ERWSCHOCKTFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ERWSCHOCKTFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="VERFUEGCT" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20477</id>
				<id>20718</id>
				<id>20752</id>
			</blacklist>
		</xsl:variable>
		<!-- VERFUEGCT not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:VERFUEGCT &quot;Die 24-stündige Verfügbarkeit von Computertomographie ist sichergestellt&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(VERFUEGCT) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:VERFUEGCT &quot;Die 24-stündige Verfügbarkeit von Computertomographie ist sichergestellt&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="APPAUSSTFG" mode="valuesFFX">
		<!-- length(APPAUSSTFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:APPAUSSTFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SYSBEHANDFG" mode="valuesFFX">
		<!-- length(SYSBEHANDFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SYSBEHANDFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="VERSORGPRAES" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20584</id>
				<id>20718</id>
				<id>20771</id>
				<id>20836</id>
			</blacklist>
		</xsl:variable>
		<!-- VERSORGPRAES not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:VERSORGPRAES &quot;Die ärztliche Versorgung in der Fachabteilung ist durch eine &#10;täglich 24 stündige Arztpräsenz im Krankenhaus (Bereitschaftsdienst möglich) sichergestellt, die auch eine jederzeitige operative Patientenversorgung gewährleistet&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(VERSORGPRAES) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:VERSORGPRAES &quot;Die ärztliche Versorgung in der Fachabteilung ist durch eine &#10;täglich 24 stündige Arztpräsenz im Krankenhaus (Bereitschaftsdienst möglich) sichergestellt, die auch eine jederzeitige operative Patientenversorgung gewährleistet&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="ERWSCHOCKT" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20458</id>
				<id>20718</id>
				<id>20737</id>
			</blacklist>
		</xsl:variable>
		<!-- ERWSCHOCKT not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ERWSCHOCKT &quot;B - Personal - Erweitertes Schockraumteam:&#13;&#10;Erfüllung aller 13 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(ERWSCHOCKT) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ERWSCHOCKT &quot;B - Personal - Erweitertes Schockraumteam:&#13;&#10;Erfüllung aller 13 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SOPMEDFG" mode="valuesFFX">
		<!-- length(SOPMEDFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SOPMEDFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="AERZTLEITFG" mode="valuesFFX">
		<!-- length(AERZTLEITFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:AERZTLEITFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="PHYSATEM" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20587</id>
				<id>20718</id>
				<id>20774</id>
				<id>20839</id>
			</blacklist>
		</xsl:variable>
		<!-- PHYSATEM not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:PHYSATEM &quot;Physiotherapie durch einen Physiotherapeuten/ eine &#10;Physiotherapeutin steht täglich für jeden Patienten zur &#10;Atemgymnastik und frühzeitigen Mobilisierung ab dem ersten postoperativen Tag zur Verfügung&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(PHYSATEM) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:PHYSATEM &quot;Physiotherapie durch einen Physiotherapeuten/ eine &#10;Physiotherapeutin steht täglich für jeden Patienten zur &#10;Atemgymnastik und frühzeitigen Mobilisierung ab dem ersten postoperativen Tag zur Verfügung&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="VERSORGPRAESFG" mode="valuesFFX">
		<!-- length(VERSORGPRAESFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:VERSORGPRAESFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="AERZTLEIT" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20456</id>
				<id>20718</id>
				<id>20735</id>
			</blacklist>
		</xsl:variable>
		<!-- AERZTLEIT not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:AERZTLEIT &quot;B - Personal - Ärztliche Leitungsebene: &#13;&#10;Erfüllung aller 2 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(AERZTLEIT) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:AERZTLEIT &quot;B - Personal - Ärztliche Leitungsebene: &#13;&#10;Erfüllung aller 2 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="FAVERFUEGBFG" mode="valuesFFX">
		<!-- length(FAVERFUEGBFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:FAVERFUEGBFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="ERFMIND" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20718</id>
				<id>20808</id>
				<id>20810</id>
				<id>20847</id>
				<id>20855</id>
			</blacklist>
		</xsl:variable>
		<!-- ERFMIND not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ERFMIND &quot;Erfüllung der Mindestanforderungen gemäß Checkliste&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(ERFMIND) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ERFMIND &quot;Erfüllung der Mindestanforderungen gemäß Checkliste&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SOPGERI" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20593</id>
				<id>20718</id>
				<id>20780</id>
				<id>20845</id>
			</blacklist>
		</xsl:variable>
		<!-- SOPGERI not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SOPGERI &quot;Der Krankenhausstandort verfügt über die SOP &quot;Orthogeriatrische Zusammenarbeit für Patienten mit positivem geriatrischen Screening&quot;&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(SOPGERI) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SOPGERI &quot;Der Krankenhausstandort verfügt über die SOP &quot;Orthogeriatrische Zusammenarbeit für Patienten mit positivem geriatrischen Screening&quot;&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="AUSSENDOFG" mode="valuesFFX">
		<!-- length(AUSSENDOFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:AUSSENDOFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="NOTFZUSATZWFG" mode="valuesFFX">
		<!-- length(NOTFZUSATZWFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:NOTFZUSATZWFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SOPPHYSFG" mode="valuesFFX">
		<!-- length(SOPPHYSFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SOPPHYSFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="MINFAA" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20466</id>
				<id>20718</id>
				<id>20744</id>
			</blacklist>
		</xsl:variable>
		<!-- MINFAA not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:MINFAA &quot;Das Krankenhaus verfügt mindestens über die Fachabteilung Chirurgie oder&#13;&#10;Unfallchirurgie oder Allgemeine Chirurgie oder Orthopädie oder&#13;&#10;Orthopädie und Unfallchirurgie am Standort&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(MINFAA) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:MINFAA &quot;Das Krankenhaus verfügt mindestens über die Fachabteilung Chirurgie oder&#13;&#10;Unfallchirurgie oder Allgemeine Chirurgie oder Orthopädie oder&#13;&#10;Orthopädie und Unfallchirurgie am Standort&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="WEITERVERLUFTFG" mode="valuesFFX">
		<!-- length(WEITERVERLUFTFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:WEITERVERLUFTFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="MINFAAFG" mode="valuesFFX">
		<!-- length(MINFAAFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:MINFAAFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="WEITERVERLUFT" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20478</id>
				<id>20718</id>
				<id>20753</id>
			</blacklist>
		</xsl:variable>
		<!-- WEITERVERLUFT not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:WEITERVERLUFT &quot;Es besteht die Möglichkeit der Weiterverlegung eines Notfallpatienten auf dem Luftweg in ein Krankenhaus der Basisnotfallversorgung oder einer höheren Stufe&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(WEITERVERLUFT) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:WEITERVERLUFT &quot;Es besteht die Möglichkeit der Weiterverlegung eines Notfallpatienten auf dem Luftweg in ein Krankenhaus der Basisnotfallversorgung oder einer höheren Stufe&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="NOTFFORTBFG" mode="valuesFFX">
		<!-- length(NOTFFORTBFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:NOTFFORTBFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="INTENBBEATM" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20474</id>
				<id>20718</id>
				<id>20749</id>
			</blacklist>
		</xsl:variable>
		<!-- INTENBBEATM not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:INTENBBEATM &quot;Mindestens drei Intensivtherapiebetten sind zur Versorgung &#10;beatmeter Patienten ausgestattet&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(INTENBBEATM) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:INTENBBEATM &quot;Mindestens drei Intensivtherapiebetten sind zur Versorgung &#10;beatmeter Patienten ausgestattet&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SCHOCKFG" mode="valuesFFX">
		<!-- length(SCHOCKFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SCHOCKFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SOPPERIFG" mode="valuesFFX">
		<!-- length(SOPPERIFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SOPPERIFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="ANFTRAUMA" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20455</id>
				<id>20456</id>
				<id>20457</id>
				<id>20458</id>
				<id>20459</id>
				<id>20460</id>
				<id>20461</id>
				<id>20463</id>
				<id>20464</id>
				<id>20465</id>
				<id>20466</id>
				<id>20467</id>
				<id>20468</id>
				<id>20472</id>
				<id>20473</id>
				<id>20474</id>
				<id>20475</id>
				<id>20476</id>
				<id>20477</id>
				<id>20478</id>
				<id>20581</id>
				<id>20718</id>
				<id>20734</id>
				<id>20735</id>
				<id>20736</id>
				<id>20737</id>
				<id>20738</id>
				<id>20739</id>
				<id>20740</id>
				<id>20741</id>
				<id>20742</id>
				<id>20743</id>
				<id>20744</id>
				<id>20745</id>
				<id>20746</id>
				<id>20747</id>
				<id>20748</id>
				<id>20749</id>
				<id>20750</id>
				<id>20751</id>
				<id>20752</id>
				<id>20753</id>
				<id>20768</id>
				<id>20833</id>
			</blacklist>
		</xsl:variable>
		<!-- ANFTRAUMA not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ANFTRAUMA &quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(ANFTRAUMA) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ANFTRAUMA &quot;Die Anforderungen an ein überregionales Traumazentrum sind vollständig erfüllt&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="FAKVERFPERS" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20459</id>
				<id>20718</id>
				<id>20738</id>
			</blacklist>
		</xsl:variable>
		<!-- FAKVERFPERS not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:FAKVERFPERS &quot;B - Personal - Fakultativ verfügbares Personal:&#13;&#10;Erfüllung aller 3 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(FAKVERFPERS) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:FAKVERFPERS &quot;B - Personal - Fakultativ verfügbares Personal:&#13;&#10;Erfüllung aller 3 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="STRUKTPROZ" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20455</id>
				<id>20718</id>
				<id>20734</id>
			</blacklist>
		</xsl:variable>
		<!-- STRUKTPROZ not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:STRUKTPROZ &quot;A - Strukturen und Prozesse:&#13;&#10;Erfüllung aller 12 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(STRUKTPROZ) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:STRUKTPROZ &quot;A - Strukturen und Prozesse:&#13;&#10;Erfüllung aller 12 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="INTENBBEATMFG" mode="valuesFFX">
		<!-- length(INTENBBEATMFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:INTENBBEATMFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="NOTFPWEITERB" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20641</id>
				<id>20644</id>
			</blacklist>
		</xsl:variable>
		<!-- NOTFPWEITERB not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:NOTFPWEITERB &quot;Die für die Notfallversorgung benannte Pflegekraft verfügt &#10;über die Weiterbildung „Notfallpflege“&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(NOTFPWEITERB) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:NOTFPWEITERB &quot;Die für die Notfallversorgung benannte Pflegekraft verfügt &#10;über die Weiterbildung „Notfallpflege“&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="ANFVOLLSTAFG" mode="valuesFFX">
		<!-- length(ANFVOLLSTAFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ANFVOLLSTAFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="PHYSATEMFG" mode="valuesFFX">
		<!-- length(PHYSATEMFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:PHYSATEMFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SOPOPVFG" mode="valuesFFX">
		<!-- length(SOPOPVFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SOPOPVFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="FAKVERFPERSFG" mode="valuesFFX">
		<!-- length(FAKVERFPERSFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:FAKVERFPERSFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SOPPERI" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20589</id>
				<id>20718</id>
				<id>20776</id>
				<id>20841</id>
			</blacklist>
		</xsl:variable>
		<!-- SOPPERI not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SOPPERI &quot;Der Krankenhausstandort verfügt über die SOP &quot;Perioperative &#10;Planung: Priorisierung von Eingriffen, Planung von OP Kapazitäten, Planung von OP-Teams&quot;&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(SOPPERI) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SOPPERI &quot;Der Krankenhausstandort verfügt über die SOP &quot;Perioperative &#10;Planung: Priorisierung von Eingriffen, Planung von OP Kapazitäten, Planung von OP-Teams&quot;&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SOPGERIFG" mode="valuesFFX">
		<!-- length(SOPGERIFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SOPGERIFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="INTENBETT" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20473</id>
				<id>20718</id>
				<id>20748</id>
			</blacklist>
		</xsl:variable>
		<!-- INTENBETT not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:INTENBETT &quot;Die Intensivstation verfügt über mindestens sechs Intensivtherapiebetten&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(INTENBETT) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:INTENBETT &quot;Die Intensivstation verfügt über mindestens sechs Intensivtherapiebetten&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="GERIKOMPFG" mode="valuesFFX">
		<!-- length(GERIKOMPFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:GERIKOMPFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="NOTFVERANT" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20468</id>
				<id>20640</id>
				<id>20641</id>
				<id>20642</id>
				<id>20643</id>
				<id>20644</id>
				<id>20645</id>
				<id>20718</id>
				<id>20746</id>
			</blacklist>
		</xsl:variable>
		<!-- NOTFVERANT not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:NOTFVERANT &quot;Es sind jeweils ein für die Notfallversorgung verantwortlicher &#10;Arzt und eine Pflegekraft benannt, die fachlich und &#10;organisatorisch eindeutig der Versorgung von Notfällen zugeordnet und im Bedarfsfall verfügbar sind&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(NOTFVERANT) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:NOTFVERANT &quot;Es sind jeweils ein für die Notfallversorgung verantwortlicher &#10;Arzt und eine Pflegekraft benannt, die fachlich und &#10;organisatorisch eindeutig der Versorgung von Notfällen zugeordnet und im Bedarfsfall verfügbar sind&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="ANFVOLLSTA" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>18908</id>
				<id>19585</id>
				<id>20718</id>
			</blacklist>
		</xsl:variable>
		<!-- ANFVOLLSTA not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ANFVOLLSTA &quot;Die Anforderungen gemäß § 10 Abs. 2 QSFFx-RL (Ausnahmetatbestand) sind vollständig erfüllt&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(ANFVOLLSTA) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ANFVOLLSTA &quot;Die Anforderungen gemäß § 10 Abs. 2 QSFFx-RL (Ausnahmetatbestand) sind vollständig erfüllt&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="NOTAUFN" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20460</id>
				<id>20718</id>
				<id>20739</id>
			</blacklist>
		</xsl:variable>
		<!-- NOTAUFN not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:NOTAUFN &quot;C - Räumliche Anforderungen - Notaufnahme:&#13;&#10;Erfüllung aller 8 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(NOTAUFN) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:NOTAUFN &quot;C - Räumliche Anforderungen - Notaufnahme:&#13;&#10;Erfüllung aller 8 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="ANFVOLLSTB" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>19810</id>
				<id>19878</id>
				<id>20718</id>
			</blacklist>
		</xsl:variable>
		<!-- ANFVOLLSTB not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ANFVOLLSTB &quot;Die Anforderungen gemäß § 12 Abs. 1 QSFFx-RL (Übergangsregelung zur geriatrischen Versorgung) sind erfüllt&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(ANFVOLLSTB) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ANFVOLLSTB &quot;Die Anforderungen gemäß § 12 Abs. 1 QSFFx-RL (Übergangsregelung zur geriatrischen Versorgung) sind erfüllt&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="INTENBETTFG" mode="valuesFFX">
		<!-- length(INTENBETTFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:INTENBETTFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SOPBLUTFG" mode="valuesFFX">
		<!-- length(SOPBLUTFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SOPBLUTFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="BATSCHOCKFG" mode="valuesFFX">
		<!-- length(BATSCHOCKFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:BATSCHOCKFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SOPEINWFG" mode="valuesFFX">
		<!-- length(SOPEINWFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SOPEINWFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="MINFAIMFG" mode="valuesFFX">
		<!-- length(MINFAIMFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:MINFAIMFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="STICHTAG" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20574</id>
				<id>20723</id>
				<id>20830</id>
				<id>20853</id>
				<id>20854</id>
				<id>20856</id>
				<id>20857</id>
				<id>20858</id>
				<id>20859</id>
			</blacklist>
		</xsl:variable>
		<!-- does not match (0[1-9]|[12][0-9]|3[01])[\.](0[1-9]|1[012])[\.](19|20)\d{2} -->
		<xsl:if test="iqtig:exists(@V) and not(matches(@V, '^(0[1-9]|[12][0-9]|3[01])[\.](0[1-9]|1[012])[\.](19|20)\d{2}$'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001018"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:STICHTAG &quot;Stichtag&quot; entspricht nicht der vorgegebenen Formatanweisung &quot;(0[1-9]|[12][0-9]|3[01])[\.](0[1-9]|1[012])[\.](19|20)\d&amp;#123;2&amp;#125;&quot;."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(STICHTAG) > 10 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 10">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:STICHTAG &quot;Stichtag&quot; überschreitet die zulässige Feldlänge 10."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- STICHTAG not a valid date -->
		<xsl:if test="iqtig:exists(@V) and not(iqtig:date_string(@V) castable as xs:date)">
			<error>
				<error_type V="WERT"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:STICHTAG &quot;Stichtag&quot; ist kein gültiges Datum."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="ANFVOLLSTBFG" mode="valuesFFX">
		<!-- length(ANFVOLLSTBFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ANFVOLLSTBFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="MINFAIM" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>18908</id>
				<id>19585</id>
				<id>20467</id>
				<id>20718</id>
				<id>20745</id>
			</blacklist>
		</xsl:variable>
		<!-- MINFAIM not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:MINFAIM &quot;Das Krankenhaus verfügt mindestens über die Fachabteilung Innere Medizin am Standort&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(MINFAIM) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:MINFAIM &quot;Das Krankenhaus verfügt mindestens über die Fachabteilung Innere Medizin am Standort&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="STRUKTPROZFG" mode="valuesFFX">
		<!-- length(STRUKTPROZFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:STRUKTPROZFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="FAVERFUEGB" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20472</id>
				<id>20718</id>
				<id>20747</id>
			</blacklist>
		</xsl:variable>
		<!-- FAVERFUEGB not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:FAVERFUEGB &quot;Es ist jeweils ein Facharzt im Gebiet Innere Medizin,&#10;Chirurgie und Anästhesie innerhalb von maximal 30 Minuten am Patienten verfügbar&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(FAVERFUEGB) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:FAVERFUEGB &quot;Es ist jeweils ein Facharzt im Gebiet Innere Medizin,&#10;Chirurgie und Anästhesie innerhalb von maximal 30 Minuten am Patienten verfügbar&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SOPPHYS" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20594</id>
				<id>20718</id>
				<id>20781</id>
				<id>20846</id>
			</blacklist>
		</xsl:variable>
		<!-- SOPPHYS not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SOPPHYS &quot;Der Krankenhausstandort verfügt über die SOP &quot;Physiotherapeutische Maßnahmen&quot;&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(SOPPHYS) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:SOPPHYS &quot;Der Krankenhausstandort verfügt über die SOP &quot;Physiotherapeutische Maßnahmen&quot;&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="ANLFA" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20583</id>
				<id>20718</id>
				<id>20770</id>
				<id>20835</id>
			</blacklist>
		</xsl:variable>
		<!-- ANLFA not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ANLFA &quot;Die Durchführung der mit den Kombinationen aus Diagnosen &#10;und Prozeduren nach Anlage 1 QSFFx-RL beschriebenen Operationen erfolgt &#10;durch oder unter Anleitung und Aufsicht einer Fachärztin oder eines Facharztes für Chirurgie&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(ANLFA) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ANLFA &quot;Die Durchführung der mit den Kombinationen aus Diagnosen &#10;und Prozeduren nach Anlage 1 QSFFx-RL beschriebenen Operationen erfolgt &#10;durch oder unter Anleitung und Aufsicht einer Fachärztin oder eines Facharztes für Chirurgie&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="VERFUEGCTFG" mode="valuesFFX">
		<!-- length(VERFUEGCTFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:VERFUEGCTFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="FAORGEINHEITFG" mode="valuesFFX">
		<!-- length(FAORGEINHEITFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:FAORGEINHEITFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="ANLFAFG" mode="valuesFFX">
		<!-- length(ANLFAFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ANLFAFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="NOTAUFNFG" mode="valuesFFX">
		<!-- length(NOTAUFNFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:NOTAUFNFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="OPABT" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20461</id>
				<id>20718</id>
				<id>20740</id>
			</blacklist>
		</xsl:variable>
		<!-- OPABT not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:OPABT &quot;C - Räumliche Anforderungen - Operationsabteilung:&#13;&#10;Erfüllung der Mindestanforderung gemäß dem Anhang zu Anlage 3&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(OPABT) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:OPABT &quot;C - Räumliche Anforderungen - Operationsabteilung:&#13;&#10;Erfüllung der Mindestanforderung gemäß dem Anhang zu Anlage 3&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="APPAUSSTOPFG" mode="valuesFFX">
		<!-- length(APPAUSSTOPFG) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:APPAUSSTOPFG &quot;Freiwillige Angabe der Gründe für die Nichterfüllung&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="PERSINTENSIV" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20463</id>
				<id>20718</id>
				<id>20741</id>
			</blacklist>
		</xsl:variable>
		<!-- PERSINTENSIV not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:PERSINTENSIV &quot;D - Personelle Ausstattung der Intensivstation:&#13;&#10;Erfüllung aller 8 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(PERSINTENSIV) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:PERSINTENSIV &quot;D - Personelle Ausstattung der Intensivstation:&#13;&#10;Erfüllung aller 8 Mindestanforderungen gemäß dem Anhang zu Anlage 3&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="AENDMELD" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>19820</id>
				<id>19822</id>
				<id>20511</id>
				<id>20697</id>
				<id>20768</id>
				<id>20769</id>
				<id>20770</id>
				<id>20771</id>
				<id>20772</id>
				<id>20773</id>
				<id>20774</id>
				<id>20775</id>
				<id>20776</id>
				<id>20777</id>
				<id>20778</id>
				<id>20779</id>
				<id>20780</id>
				<id>20781</id>
				<id>20784</id>
				<id>20785</id>
				<id>20810</id>
				<id>20829</id>
				<id>20833</id>
				<id>20834</id>
				<id>20835</id>
				<id>20836</id>
				<id>20837</id>
				<id>20838</id>
				<id>20839</id>
				<id>20840</id>
				<id>20841</id>
				<id>20842</id>
				<id>20843</id>
				<id>20844</id>
				<id>20845</id>
				<id>20846</id>
				<id>20847</id>
			</blacklist>
		</xsl:variable>
		<!-- AENDMELD not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:AENDMELD &quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; ist kein gültiger Code des Schlüssels Jleer (Ja / &lt;leer&gt;)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(AENDMELD) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:AENDMELD &quot;Meldung der Nicht- oder Wiedererfüllung von Mindestanforderungen gemäß § 6 Abs. 1 Satz 3 QSFFx-RL&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="NOTFZUSATZW" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20640</id>
				<id>20643</id>
			</blacklist>
		</xsl:variable>
		<!-- NOTFZUSATZW not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:NOTFZUSATZW &quot;Der für die Notfallversorgung benannte Arzt verfügt über die Zusatzweiterbildung „Klinische Akut- und Notfallmedizin“&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(NOTFZUSATZW) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:NOTFZUSATZW &quot;Der für die Notfallversorgung benannte Arzt verfügt über die Zusatzweiterbildung „Klinische Akut- und Notfallmedizin“&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="FAORGEINHEIT" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20582</id>
				<id>20718</id>
				<id>20769</id>
				<id>20834</id>
			</blacklist>
		</xsl:variable>
		<!-- FAORGEINHEIT not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('0', '1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:FAORGEINHEIT &quot;Die Versorgung der Patienten erfolgt in einer ärztlich geleiteten Fachabteilung, die eine fachlich unabhängige, abgrenzbare und organisatorisch eigenständige Organisationseinheit am Standort des Krankenhauses ist&quot; ist kein gültiger Code des Schlüssels JN (Ja/Nein)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(FAORGEINHEIT) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:FAORGEINHEIT &quot;Die Versorgung der Patienten erfolgt in einer ärztlich geleiteten Fachabteilung, die eine fachlich unabhängige, abgrenzbare und organisatorisch eigenständige Organisationseinheit am Standort des Krankenhauses ist&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="ANMELDEJ" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20511</id>
				<id>20574</id>
				<id>20581</id>
				<id>20582</id>
				<id>20583</id>
				<id>20584</id>
				<id>20585</id>
				<id>20586</id>
				<id>20587</id>
				<id>20588</id>
				<id>20589</id>
				<id>20590</id>
				<id>20591</id>
				<id>20592</id>
				<id>20593</id>
				<id>20594</id>
				<id>20701</id>
				<id>20808</id>
				<id>20829</id>
				<id>20830</id>
				<id>20833</id>
				<id>20834</id>
				<id>20835</id>
				<id>20836</id>
				<id>20837</id>
				<id>20838</id>
				<id>20839</id>
				<id>20840</id>
				<id>20841</id>
				<id>20842</id>
				<id>20843</id>
				<id>20844</id>
				<id>20845</id>
				<id>20846</id>
				<id>20847</id>
				<id>20849</id>
				<id>20850</id>
			</blacklist>
		</xsl:variable>
		<!-- ANMELDEJ not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ANMELDEJ &quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; ist kein gültiger Code des Schlüssels Jleer (Ja / &lt;leer&gt;)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(ANMELDEJ) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ANMELDEJ &quot;Nachweis über die Erfüllung der Mindestanforderungen&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="ABMELD" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20697</id>
				<id>20701</id>
				<id>20723</id>
				<id>20829</id>
				<id>20830</id>
				<id>20858</id>
				<id>20859</id>
			</blacklist>
		</xsl:variable>
		<!-- ABMELD not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('1'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ABMELD &quot;Abmeldung vom Nachweisverfahren&quot; ist kein gültiger Code des Schlüssels Jleer (Ja / &lt;leer&gt;)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(ABMELD) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ABMELD &quot;Abmeldung vom Nachweisverfahren&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="LFDCHL" mode="valuesFFX">
		<!-- does not match [\+\-]?[0-9]+ -->
		<xsl:if test="iqtig:exists(@V) and not(matches(@V, '^[\+\-]?[0-9]+$'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001018"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:LFDCHL &quot;laufende Nummer der Checkliste&quot; entspricht nicht der vorgegebenen Formatanweisung &quot;[\+\-]?[0-9]+&quot;."/>
			</error>
		</xsl:if>
		<!-- not filled out -->
		<xsl:if test="not(iqtig:exists(@V)) and not(exists(preceding-sibling::LFDCHL))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001022"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Das Datenfeld FFX:C:LFDCHL &quot;laufende Nummer der Checkliste&quot; muss einen gültigen Wert enthalten."/>
			</error>
		</xsl:if>
		<!-- length(LFDCHL) > 3 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 3">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:LFDCHL &quot;laufende Nummer der Checkliste&quot; überschreitet die zulässige Feldlänge 3."/>
			</error>
		</xsl:if>
		<!-- LFDCHL < 1.0 -->
		<xsl:if test="iqtig:is_number(@V) and iqtig:compare(@V, 1.0,'&lt;')">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001021"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:LFDCHL &quot;laufende Nummer der Checkliste&quot; ist kleiner als 1.0."/>
			</error>
		</xsl:if>
		<!-- LFDCHL > 999.0 -->
		<xsl:if test="iqtig:is_number(@V) and iqtig:compare(@V, 999.0,'&gt;')">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001021"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:LFDCHL &quot;laufende Nummer der Checkliste&quot; ist größer als 999.0."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="ARTNACHWEIS" mode="valuesFFX">
		<xsl:variable name="blacklist">
			<blacklist>
				<id>20726</id>
				<id>20849</id>
				<id>20850</id>
				<id>20853</id>
				<id>20854</id>
				<id>20855</id>
				<id>20856</id>
				<id>20857</id>
			</blacklist>
		</xsl:variable>
		<!-- ARTNACHWEIS not a valid key value -->
		<xsl:if test="iqtig:exists(@V) and iqtig:NICHTIN(., ('1', '3', '2'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001020"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ARTNACHWEIS &quot;Art des Nachweises&quot; ist kein gültiger Code des Schlüssels ARTNACHWEIS (Varianten der Dokumentation des Nachweis zwischen dem 15.11.-31.12. am Ende des Erfassungsjahres)."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
		<!-- length(ARTNACHWEIS) > 1 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFX:C:ARTNACHWEIS &quot;Art des Nachweises&quot; überschreitet die zulässige Feldlänge 1."/>
			</error>
			<xsl:copy-of select="$blacklist"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="case[$prechecks_ok and not(case_admin/action/@V = 'delete') and not(qs_data/@xsi:type = 'qs_data_mds_type') and (qs_data/@module = 'FFXE')]" mode="specific">
		<xsl:variable name="value_errors">
			<xsl:apply-templates mode="valuesFFXE" select="qs_data/B/felder/*"/>
		</xsl:variable>
		<xsl:copy-of select="$value_errors/error"/>
		<xsl:apply-templates mode="formsFFXE" select="qs_data/B"/>
		<xsl:apply-templates mode="rulesFFXE" select="qs_data/B">
			<xsl:with-param name="blacklist_ids" select="$value_errors/blacklist/id"/>
		</xsl:apply-templates>
	</xsl:template>
	<xsl:template match="B" mode="rulesFFXE">
		<xsl:param name="blacklist_ids"/>
	</xsl:template>
	<xsl:template match="B" mode="formsFFXE"/>
	<xsl:template match="EMAIL" mode="valuesFFXE">
		<!-- does not match [A-Za-z0-9._%+\-]+@[A-Za-z0-9.\-]+\.[A-Za-z]{2,} -->
		<xsl:if test="iqtig:exists(@V) and not(matches(@V, '^[A-Za-z0-9._%+\-]+@[A-Za-z0-9.\-]+\.[A-Za-z]{2,}$'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001018"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFXE:B:EMAIL &quot;E-Mail&quot; entspricht nicht der vorgegebenen Formatanweisung &quot;[A-Za-z0-9._%+\-]+@[A-Za-z0-9.\-]+\.[A-Za-z]&amp;#123;2,&amp;#125;&quot;."/>
			</error>
		</xsl:if>
		<!-- not filled out -->
		<xsl:if test="not(iqtig:exists(@V)) and not(exists(preceding-sibling::EMAIL))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001022"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Das Datenfeld FFXE:B:EMAIL &quot;E-Mail&quot; muss einen gültigen Wert enthalten."/>
			</error>
		</xsl:if>
		<!-- length(EMAIL) > 1000 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 1000">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFXE:B:EMAIL &quot;E-Mail&quot; überschreitet die zulässige Feldlänge 1000."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:template match="DokAbschlDat" mode="valuesFFXE">
		<!-- does not match (0[1-9]|[12][0-9]|3[01])[\.](0[1-9]|1[012])[\.](19|20)\d{2} -->
		<xsl:if test="iqtig:exists(@V) and not(matches(@V, '^(0[1-9]|[12][0-9]|3[01])[\.](0[1-9]|1[012])[\.](19|20)\d{2}$'))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001018"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFXE:B:DokAbschlDat entspricht nicht der vorgegebenen Formatanweisung &quot;(0[1-9]|[12][0-9]|3[01])[\.](0[1-9]|1[012])[\.](19|20)\d&amp;#123;2&amp;#125;&quot;."/>
			</error>
		</xsl:if>
		<!-- not filled out -->
		<xsl:if test="not(iqtig:exists(@V)) and not(exists(preceding-sibling::DokAbschlDat))">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001022"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Das Datenfeld FFXE:B:DokAbschlDat muss einen gültigen Wert enthalten."/>
			</error>
		</xsl:if>
		<!-- length(DokAbschlDat) > 10 -->
		<xsl:if test="iqtig:exists(@V) and string-length(@V) &gt; 10">
			<error>
				<error_type V="WERT"/>
				<rule_id V="1001019"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFXE:B:DokAbschlDat überschreitet die zulässige Feldlänge 10."/>
			</error>
		</xsl:if>
		<!-- DokAbschlDat not a valid date -->
		<xsl:if test="iqtig:exists(@V) and not(iqtig:date_string(@V) castable as xs:date)">
			<error>
				<error_type V="WERT"/>
				<rule_type V="H"/>
				<list V="{iqtig:feld(.)}"/>
				<error_message V="Der Wert '{@V}' des Datenfeldes FFXE:B:DokAbschlDat ist kein gültiges Datum."/>
			</error>
		</xsl:if>
	</xsl:template>
	<xsl:function name="iqtig:replace_icd">
		<xsl:param name="value"/>
		<xsl:for-each select="$value">
			<xsl:element name="{./local-name()}">
				<xsl:attribute name="V">
					<xsl:value-of select="replace(./@V, '[RLBrlbVAZGvazg!\*\+†#]+$', '')"/>
				</xsl:attribute>
			</xsl:element>
		</xsl:for-each>
	</xsl:function>
	<xsl:function name="iqtig:replace_ops">
		<xsl:param name="value"/>
		<xsl:for-each select="$value">
			<xsl:element name="{./local-name()}">
				<xsl:attribute name="V">
					<xsl:value-of select="replace(./@V, ':[rRbBlL]$', '')"/>
				</xsl:attribute>
			</xsl:element>
		</xsl:for-each>
	</xsl:function>
	<xsl:function as="xs:boolean" name="iqtig:reg_no_hessen">
		<xsl:param name="reg_no"/>
		<xsl:value-of select="starts-with($reg_no, 'HE')"/>
	</xsl:function>
	<xsl:function as="xs:string" name="iqtig:get_status">
		<xsl:param name="protocol"/>
		<xsl:param name="global"/>
		<xsl:choose>
			<xsl:when test="$global">
				<xsl:choose>
					<xsl:when test="every $case in $protocol satisfies (iqtig:get_status($case, false()) = 'ERROR')">
						<xsl:value-of select="'ERROR'"/>
					</xsl:when>
					<xsl:when test="some $case in $protocol satisfies (iqtig:get_status($case, false()) != 'OK')">
						<xsl:value-of select="'WARNING'"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="'OK'"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="$protocol//error[rule_type/@V = 'H' or not(rule_type)]">
						<xsl:value-of select="'ERROR'"/>
					</xsl:when>
					<xsl:when test="$protocol//error/rule_type[@V = 'W' or @V = 'D']">
						<xsl:value-of select="'WARNING'"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="'OK'"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:function>
	<xsl:function as="xs:string" name="iqtig:get_status_document">
		<xsl:param name="protocol"/>
		<xsl:param name="status_document"/>
		<xsl:param name="status_header"/>
		<xsl:variable name="status" select="iqtig:get_status($protocol, true())"/>
		<xsl:choose>
			<xsl:when test="$status_document = 'ERROR' or $status = 'ERROR' or $status_header = 'ERROR'">
				<xsl:value-of select="'ERROR'"/>
			</xsl:when>
			<xsl:when test="$status_document = 'WARNING' or $status = 'WARNING' or $status_header = 'WARNING'">
				<xsl:value-of select="'WARNING'"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'OK'"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:function>
	<xsl:function as="xs:string" name="iqtig:get_status_case">
		<xsl:param name="protocol"/>
		<xsl:param name="status_case"/>
		<xsl:variable name="status" select="iqtig:get_status($protocol, false())"/>
		<xsl:choose>
			<xsl:when test="$status_case = 'ERROR' or $status = 'ERROR'">
				<xsl:value-of select="'ERROR'"/>
			</xsl:when>
			<xsl:when test="$status_case = 'WARNING' or $status = 'WARNING'">
				<xsl:value-of select="'WARNING'"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'OK'"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:function>
	<xsl:function as="xs:double" name="iqtig:number">
		<xsl:param name="value"/>
		<xsl:choose>
			<xsl:when test="iqtig:is_date($value)">
				<xsl:value-of select="(iqtig:Datum($value) - xs:date('1970-01-01')) div xs:dayTimeDuration('P1D')"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="number(replace(xs:string($value), ',', '.'))"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:function>
	<xsl:function as="xs:boolean" name="iqtig:compare">
		<xsl:param name="value1"/>
		<xsl:param name="value2"/>
		<xsl:param name="operator"/>
		<xsl:choose>
			<xsl:when test="not(iqtig:exists($value1)) and not(iqtig:exists($value2))">
				<xsl:choose>
					<xsl:when test="$operator = '=' or $operator = '&lt;=' or $operator = '&gt;='">
						<xsl:value-of select="true()"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="false()"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="(not(iqtig:exists($value1)) and iqtig:exists($value2)) or (not(iqtig:exists($value2)) and iqtig:exists($value1))">			
				<xsl:choose>
					<xsl:when test="$operator = '!='">
						<xsl:value-of select="true()"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="false()"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="iqtig:is_number($value1) and iqtig:is_number($value2)">
				<xsl:value-of select="iqtig:compareHelper(iqtig:number($value1), iqtig:number($value2), $operator)"/>
			</xsl:when>
			<xsl:when test="iqtig:is_date($value1) and iqtig:is_date($value2)">
				<xsl:value-of select="iqtig:compareHelper(iqtig:Datum($value1), iqtig:Datum($value2), $operator)"/>
			</xsl:when>
			<xsl:when test="iqtig:is_time($value1) and iqtig:is_time($value2)">
				<xsl:value-of select="iqtig:compareHelper(iqtig:Zeit($value1), iqtig:Zeit($value2), $operator)"/>
			</xsl:when>
			<xsl:when test="iqtig:is_boolean($value1) and iqtig:is_boolean($value2)">
				<xsl:value-of select="iqtig:compareHelper($value1, $value2, $operator)"/>
			</xsl:when>
			<xsl:when test="true()">
				<xsl:value-of select="iqtig:compareHelper(xs:string($value1), xs:string($value2), $operator)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="$operator = '!='">
						<xsl:value-of select="true()"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="false()"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:function>	
		<xsl:function as="xs:boolean" name="iqtig:listcompare">
		<xsl:param name="list"/>
		<xsl:param name="regexp"/>
		<xsl:param name="operator1"/>
		<xsl:param name="operator2"/>
		<xsl:variable name="zwischenergebnis">	
			<xsl:for-each select="distinct-values($list/@V)">
				<xsl:if test="iqtig:compare(matches(., $regexp), $operator1, $operator2)">
					<xsl:value-of select="true()"/>	
				</xsl:if>
			</xsl:for-each>
		</xsl:variable>
		<xsl:value-of>
			<xsl:choose>
				<xsl:when test="string-length($zwischenergebnis) &gt; 0">
					<xsl:value-of select="true()"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="false()"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:value-of>
	</xsl:function>	
	<xsl:function as="xs:boolean" name="iqtig:compareHelper">	
		<xsl:param name="value1"/>
		<xsl:param name="value2"/>
		<xsl:param name="operator"/>
		<xsl:choose>
			<xsl:when test="$operator = '&lt;='">
				<xsl:value-of select="$value1 &lt;= $value2"/>
			</xsl:when>
			<xsl:when test="$operator = '&gt;='">
				<xsl:value-of select="$value1 &gt;= $value2"/>
			</xsl:when>
			<xsl:when test="$operator = '&lt;'">
				<xsl:value-of select="$value1 &lt; $value2"/>
			</xsl:when>
			<xsl:when test="$operator = '&gt;'">
				<xsl:value-of select="$value1 &gt; $value2"/>
			</xsl:when>
			<xsl:when test="$operator = '='">
				<xsl:value-of select="lower-case(xs:string($value1)) = lower-case(xs:string($value2))"/>
			</xsl:when>
			<xsl:when test="$operator = '!='">
				<xsl:value-of select="$value1 != $value2"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="false()"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:function>
	<xsl:function as="xs:boolean" name="iqtig:is_number">
		<xsl:param name="value"/>
		<xsl:value-of select="replace(xs:string($value), ',', '.') castable as xs:decimal"/>
	</xsl:function>
	<xsl:function as="xs:boolean" name="iqtig:exists">
		<xsl:param name="value"/>		
		<xsl:value-of select="normalize-space(xs:string($value[1]))!=''"/>
	</xsl:function>
	<xsl:function as="xs:string" name="iqtig:path">
		<xsl:param name="node"/>
		<xsl:variable name="current" select="concat($node/local-name(), '[', count($node/preceding-sibling::*[local-name() = $node/local-name()]), ']/')"/>
		<xsl:choose>
			<xsl:when test="exists($node/parent::*)">
				<xsl:value-of select="concat(iqtig:path($node/parent::*), $current)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$current"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:function>	
	<xsl:function as="xs:string" name="iqtig:feld">
		<xsl:param name="field"/>
		<xsl:value-of select="concat(iqtig:bogen($field/../..), '/', $field[1]/local-name(), iqtig:get_position_suffix($field))"/>
	</xsl:function>
	<xsl:function as="xs:string" name="iqtig:bogen">
		<xsl:param name="node"/>
		<xsl:value-of select="concat($node/local-name(), iqtig:get_position_suffix($node))"/>
	</xsl:function>
	<xsl:function as="xs:boolean" name="iqtig:has_siblings">
		<xsl:param name="node"/>
		<xsl:value-of select="exists($node/preceding-sibling::*[local-name() = $node/local-name()]) or exists($node/following-sibling::*[local-name() = $node/local-name()])"/>
	</xsl:function>
	<xsl:function as="xs:string" name="iqtig:get_position_suffix">
		<xsl:param name="node"/>
		<xsl:choose>
			<xsl:when test="iqtig:has_siblings($node)">
				<xsl:value-of select="concat('[', count($node/preceding-sibling::*[local-name() = $node/local-name()]) + 1, ']')"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="''"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:function>
	<xsl:function as="xs:boolean" name="iqtig:is_boolean">
		<xsl:param name="value"/>
		<xsl:value-of select="$value castable as xs:boolean"/>
	</xsl:function>	
	<xsl:function as="xs:boolean" name="iqtig:is_date">
		<xsl:param name="value"/>
		<xsl:value-of select="iqtig:date_string($value) castable as xs:date and not(matches(xs:string($value), '^\d{4}$'))"/>
	</xsl:function>
	<xsl:function as="xs:boolean" name="iqtig:is_time">
		<xsl:param name="value"/>	
		<xsl:value-of select="iqtig:time_string($value) castable as xs:time"/>
	</xsl:function>
	<xsl:function as="xs:date" name="iqtig:Datum">
		<xsl:param name="date_param"/>
		<xsl:variable name="date" select="iqtig:date_string($date_param)"/>
		<xsl:value-of select="xs:date($date)"/>
	</xsl:function>
	<xsl:function as="xs:string" name="iqtig:date_string">
		<xsl:param name="date_param"/>
		<xsl:variable name="date" select="xs:string($date_param)"/>
		<xsl:choose>
			<!--  QQ/YYYY  -->
			<xsl:when test="matches($date, '^0?[1-4]/\d{4}$')">
				<xsl:variable name="quarter" select="number(substring-before($date, '/'))"/>
				<xsl:variable name="year" select="substring-after($date, '/')"/>
				<xsl:variable name="month" select="(($quarter - 1) * 3) + 1"/>
				<xsl:value-of select="concat($year, '-', format-number($month, '00'), '-01')"/>
			</xsl:when>
			<!--  YYYY-MM-DD  -->
			<xsl:when test="matches($date, '^\d{4}-(0?[1-9]|1[0-2])-(0?[1-9]|1[0-9]|2[0-9]|3[0-1])$')">
				<xsl:value-of select="$date"/>
			</xsl:when>
			<!--  YYYY-MM  -->
			<xsl:when test="matches($date, '^\d{4}-(0?[1-9]|1[0-2])$')">
				<xsl:value-of select="concat($date, '-01')"/>
			</xsl:when>
			<!--  MM-DD  -->
			<xsl:when test="matches($date, '^(0?[1-9]|1[0-2])-(0?[1-9]|1[0-9]|2[0-9]|3[0-1])$')">
				<xsl:value-of select="concat('1970-', $date)"/>
			</xsl:when>
			<!--  DD.MM.YYYY  -->
			<xsl:when test="matches($date, '^(0?[1-9]|1[0-9]|2[0-9]|3[0-1])\.(0?[1-9]|1[0-2])\.\d{4}$')">
				<xsl:variable name="year" select="substring-after(substring-after($date, '.'), '.')"/>
				<xsl:variable name="month" select="substring-before(substring-after($date, '.'), '.')"/>
				<xsl:variable name="day" select="substring-before($date, '.')"/>
				<xsl:value-of select="concat($year, '-', $month, '-', $day)"/>
			</xsl:when>
			<!--  MM.YYYY  -->
			<xsl:when test="matches($date, '^\d{2}\.\d{4}$')">
				<xsl:variable name="year" select="substring-after($date, '.')"/>
				<xsl:variable name="month" select="substring-before($date, '.')"/>
				<xsl:value-of select="concat($year, '-', $month, '-01')"/>
			</xsl:when>
			<!--  YYYY  -->
			<xsl:when test="matches($date, '^\d{4}$')">
				<xsl:value-of select="concat($date, '-01-01')"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'invalid'"/>
			</xsl:otherwise>			
		</xsl:choose>
	</xsl:function>
	<xsl:function as="xs:time" name="iqtig:Zeit">
		<xsl:param name="time_param"/>
		<xsl:variable name="time" select="iqtig:time_string($time_param)"/>
		<xsl:value-of select="xs:time($time)"/>
	</xsl:function>
	<xsl:function as="xs:string" name="iqtig:time_string">
		<xsl:param name="time_param"/>
		<xsl:variable name="time" select="xs:string($time_param)"/>
		<xsl:choose>
			<xsl:when test="matches($time, '^\d{2}:\d{2}:\d{2}$')">
				<xsl:value-of select="$time"/>
			</xsl:when>
			<xsl:when test="matches($time, '^\d{1}:\d{2}:\d{2}$')">
				<xsl:value-of select="concat('0', $time)"/>
			</xsl:when>
			<xsl:when test="matches($time, '^\d{1,2}:\d{2}$')">
				<xsl:value-of select="concat($time, ':00')"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'invalid'"/>
			</xsl:otherwise>			
		</xsl:choose>
	</xsl:function>
	<xsl:function as="xs:gYearMonth" name="iqtig:Quartal">
		<xsl:param name="date_param"/>
		<xsl:variable name="date" select="iqtig:Datum(xs:string($date_param))"/>
		<xsl:variable name="year" select="year-from-date($date)"/>
		<xsl:variable name="month" select="month-from-date($date)"/>
		<xsl:variable name="quarter" select="xs:integer((xs:integer($month) + 2) div 3)"/>
		<xsl:variable name="new_month" select="(($quarter - 1) * 3) + 1"/>
		<xsl:value-of select="xs:gYearMonth(concat($year, '-', format-number($new_month, '00')))"/>
	</xsl:function>
	<xsl:function as="xs:gYearMonth" name="iqtig:Monat">
		<xsl:param name="date_param"/>
		<xsl:variable name="date" select="iqtig:Datum(xs:string($date_param))"/>
		<xsl:variable name="year" select="year-from-date($date)"/>
		<xsl:variable name="month" select="month-from-date($date)"/>
		<xsl:value-of select="xs:gYearMonth(concat($year, '-', format-number($month, '00')))"/>
	</xsl:function>
	<xsl:function as="xs:integer" name="iqtig:Jahr">
		<xsl:param name="date_param"/>
		<xsl:variable name="date" select="iqtig:Datum(xs:string($date_param))"/>
		<xsl:value-of select="year-from-date($date)"/>
	</xsl:function>
	<xsl:function as="xs:boolean" name="iqtig:EINSIN">
		<xsl:param name="list1"/>
		<xsl:param name="list2"/>
		<xsl:value-of select="some $w1 in $list1 satisfies (some $w2 in $list2 satisfies iqtig:compare($w1/@V, $w2, '='))"/>
	</xsl:function>
	<xsl:function as="xs:boolean" name="iqtig:KEINSIN">
		<xsl:param name="list1"/>
		<xsl:param name="list2"/>
		<xsl:value-of select="not(iqtig:EINSIN($list1, $list2))"/>
	</xsl:function>
	<xsl:function as="xs:boolean" name="iqtig:JEDESIN">
		<xsl:param name="list1"/>
		<xsl:param name="list2"/>
		<xsl:value-of select="every $w1 in $list1 satisfies (some $w2 in $list2 satisfies iqtig:compare($w1/@V, $w2, '='))"/>
	</xsl:function>
	<xsl:function as="xs:boolean" name="iqtig:EINSNICHTIN">
		<xsl:param name="list1"/>
		<xsl:param name="list2"/>
		<xsl:value-of select="not(iqtig:JEDESIN($list1, $list2))"/>
	</xsl:function>	
	<xsl:function as="xs:boolean" name="iqtig:NICHTIN">
		<xsl:param name="list1"/>
		<xsl:param name="list2"/>
		<xsl:value-of select="iqtig:KEINSIN($list1, $list2)"/>
	</xsl:function>
	<xsl:function as="xs:boolean" name="iqtig:IN">
		<xsl:param name="list1"/>
		<xsl:param name="list2"/>
		<xsl:value-of select="not(iqtig:NICHTIN($list1, $list2))"/>
	</xsl:function>	
	<xsl:function as="xs:boolean" name="iqtig:NICHTINSCHLUESSEL">
		<xsl:param name="value"/>
		<xsl:param name="keys"/>
		<xsl:value-of select="not(some $key in $keys satisfies (string($value/@V) = string($key)))"/>
	</xsl:function>
	<xsl:function as="xs:boolean" name="iqtig:NeutralNullPlausi">
		<xsl:param name="wert1"/>
		<xsl:param name="wert2"/>
		<xsl:param name="wert3"/>
		<xsl:value-of select="iqtig:compare($wert2, $wert1, '&gt;') and iqtig:compare($wert2, $wert3, '&gt;')"/>
	</xsl:function>
	<xsl:function as="xs:boolean" name="iqtig:NeutralNullPlausi2">
		<xsl:param name="wert1"/>
		<xsl:param name="wert2"/>
		<xsl:value-of select="iqtig:compare($wert2, 0, '&gt;') and iqtig:compare($wert1, 0, '!=')"/>
	</xsl:function>	
	<xsl:function as="xs:boolean" name="iqtig:NeutralNullPlausi3">
		<xsl:param name="wert1"/>
		<xsl:param name="wert2"/>
		<xsl:param name="wert3"/>
		<xsl:value-of select="iqtig:compare($wert2, 0, '&gt;') and iqtig:compare($wert1, 0, '!=') and iqtig:compare($wert3, 0, '!=')"/>
	</xsl:function>	
	<xsl:function as="xs:integer" name="iqtig:anzahlSchaedellagen">
		<xsl:param name="liste"/>	
		<xsl:value-of select="count(iqtig:anzahlSchaedellagenHelper($liste))"/>
	</xsl:function>
	<xsl:function as="xs:string*" name="iqtig:anzahlSchaedellagenHelper">
		<xsl:param name="liste"/>
		<xsl:for-each select="distinct-values($liste/@V)">
			<xsl:if test="iqtig:compare(., 88, '=') or iqtig:compare(., 89, '=') or iqtig:compare(., 90, '=') or iqtig:compare(., 91, '=') or iqtig:compare(., 92, '=') or iqtig:compare(., 93, '=')">
				<xsl:value-of select="' '"/>
			</xsl:if>
		</xsl:for-each>
	</xsl:function>
	<xsl:function as="xs:integer*" name="iqtig:MaxGanzeZahlHelper">
		<xsl:param name="nodes"/>
		<xsl:for-each select="$nodes">
			<xsl:sort order="descending" select="."/>
			<xsl:if test="position()=1">
				<xsl:value-of select="."/>
			</xsl:if>
		</xsl:for-each>	
		<xsl:if test="count($nodes) = 0">
			<xsl:value-of select="0"/>
		</xsl:if>
	</xsl:function>
	<xsl:function as="xs:integer" name="iqtig:MaxGanzeZahl">
		<xsl:param name="nodes"/>
		<xsl:value-of select="iqtig:MaxGanzeZahlHelper($nodes)[1]"/>
	</xsl:function>
	<xsl:function as="xs:integer" name="iqtig:gestAlter">
		<xsl:param name="abstGebterm"/>
		<xsl:param name="TRAGZEITKLIN"/>
		<xsl:param name="SSBEFUND"/>
		<xsl:choose>
			<xsl:when test="iqtig:exists($abstGebterm)">
				<xsl:choose>
					<xsl:when test="some $w1 in $SSBEFUND satisfies (iqtig:compare($w1, (38), '='))">
						<xsl:choose>
							<xsl:when test="iqtig:exists($TRAGZEITKLIN) and ($TRAGZEITKLIN &gt; 18) and ($TRAGZEITKLIN &lt;= 44)">
								<xsl:value-of select="$TRAGZEITKLIN * 7"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$abstGebterm + 280"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:choose>
							<xsl:when test="iqtig:exists($TRAGZEITKLIN) and ($TRAGZEITKLIN &gt; 18) and ($TRAGZEITKLIN &lt;= 44)">
								<xsl:choose>
									<xsl:when test="abs(($TRAGZEITKLIN * 7) - ($abstGebterm + 280)) &lt; 14 and ($abstGebterm + 280) &gt;= 126 and ($abstGebterm + 280) &lt;= 308">
										<xsl:value-of select="$abstGebterm + 280"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="$TRAGZEITKLIN * 7"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$abstGebterm + 280"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="iqtig:exists($TRAGZEITKLIN) and ($TRAGZEITKLIN &gt; 18) and ($TRAGZEITKLIN &lt;= 44)">
						<xsl:value-of select="$TRAGZEITKLIN * 7"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="169"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:function>		
	<xsl:function as="xs:integer" name="iqtig:alter">
	<xsl:param name="geb"/>
	<xsl:param name="unt"/>
	<xsl:choose>
		<xsl:when test="iqtig:compare(substring($unt, 4, 2),substring($geb, 4, 2),'&lt;') or (iqtig:compare(substring($unt, 4, 2),substring($geb, 4, 2),'=') and iqtig:compare(substring($unt, 1, 2),substring($geb, 1, 2),'&lt;'))">
			<xsl:value-of select="xs:integer(substring($unt, 7, 4)) - xs:integer(substring($geb, 7,4)) - 1"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="xs:integer(substring($unt, 7, 4)) - xs:integer(substring($geb, 7, 4))"/>
		</xsl:otherwise>
	</xsl:choose>
	</xsl:function>
	<xsl:function as="xs:string" name="iqtig:MinDatum">
		<xsl:param name="nodes"/>
		<xsl:for-each select="$nodes">
			<xsl:sort order="ascending" select="iqtig:date_string(.)"/>
			<xsl:if test="position()=1">
				<xsl:value-of select="."/>
			</xsl:if>
		</xsl:for-each> 
	</xsl:function>
	<xsl:function name="iqtig:formatListe">
		<xsl:param name="seq"/>
		<xsl:param name="regex"/>
		<xsl:param name="bool"/>
		<xsl:choose>
			<xsl:when test="$bool">
				<xsl:sequence select="for $node in $seq return $node[matches(./@V,$regex)]"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:sequence select="for $node in $seq return $node[not(matches(./@V,$regex))]"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:function>
	<xsl:function as="xs:double" name="iqtig:AbstandInStunden">
		<xsl:param name="datum1"/>
		<xsl:param name="uhrzeit1"/>
		<xsl:param name="datum2"/>
		<xsl:param name="uhrzeit2"/>
		<xsl:variable name="dt1" select="xs:dateTime(concat(substring($datum1,7,4),'-',substring($datum1,4,2),'-',substring($datum1,1,2),'T',substring($uhrzeit1,1,2),':',substring($uhrzeit1,4,2),':00+01:00'))"/>
		<xsl:variable name="dt2" select="xs:dateTime(concat(substring($datum2,7,4),'-',substring($datum2,4,2),'-',substring($datum2,1,2),'T',substring($uhrzeit2,1,2),':',substring($uhrzeit2,4,2),':00+01:00'))"/>
		<xsl:variable name="dt" select="xs:duration($dt2 - $dt1)"/>
		<xsl:value-of select="days-from-duration($dt)*24 + hours-from-duration($dt) + minutes-from-duration($dt) div 60"/>
	</xsl:function>
	<xsl:function as="xs:integer" name="iqtig:AbstandInTagen">
		<xsl:param name="datum1"/>
		<xsl:param name="datum2"/>
		<xsl:value-of select="round(iqtig:AbstandInStunden($datum1,'00:00',$datum2,'00:00') div 24)"/>
	</xsl:function>
	<xsl:function as="xs:integer" name="iqtig:gestAlter">
		<xsl:param name="datum1"/>
		<xsl:param name="datum2"/>
		<xsl:param name="TRAGZEITKLIN"/>
		<xsl:param name="SSRISIKO"/>
		<xsl:value-of select="iqtig:gestAlter(iqtig:AbstandInTagen($datum2,$datum1),$TRAGZEITKLIN,$SSRISIKO)"/>
	</xsl:function>
	<xsl:function as="xs:anyAtomicType*" name="iqtig:non-distinct-values">
		<xsl:param as="xs:anyAtomicType*" name="seq"/>
		<xsl:sequence select="for $val in distinct-values($seq) return $val[count($seq[. = $val]) &gt; 1]"/>
	</xsl:function>
	<xsl:function as="xs:anyAtomicType*" name="iqtig:value-intersect">
		<xsl:param as="xs:anyAtomicType*" name="arg1"/>
		<xsl:param as="xs:anyAtomicType*" name="arg2"/>
		<xsl:sequence select="distinct-values($arg1[.=$arg2])"/>
	</xsl:function>
	<!-- equals outersection -->
	<xsl:function as="xs:anyAtomicType*" name="iqtig:value-except">
  		<xsl:param as="xs:anyAtomicType*" name="arg1"/>
  		<xsl:param as="xs:anyAtomicType*" name="arg2"/>
  		<xsl:sequence select="distinct-values($arg1[not(.=$arg2)])"/>
	</xsl:function>
	<xsl:function as="xs:boolean" name="iqtig:valueEINSIN">
		<xsl:param name="list1"/>
		<xsl:param name="list2"/>
		<xsl:value-of select="some $w1 in $list1 satisfies (some $w2 in $list2 satisfies iqtig:compare($w1, $w2, '='))"/>
	</xsl:function>
	<xsl:function as="xs:boolean" name="iqtig:valueKEINSIN">
		<xsl:param name="list1"/>
		<xsl:param name="list2"/>
		<xsl:value-of select="not(iqtig:valueEINSIN($list1, $list2))"/>
	</xsl:function>
	<xsl:function as="xs:boolean" name="iqtig:valueJEDESIN">
		<xsl:param name="list1"/>
		<xsl:param name="list2"/>
		<xsl:value-of select="every $w1 in $list1 satisfies (some $w2 in $list2 satisfies iqtig:compare($w1, $w2, '='))"/>
	</xsl:function>
	<xsl:function as="xs:boolean" name="iqtig:valueEINSNICHTIN">
		<xsl:param name="list1"/>
		<xsl:param name="list2"/>
		<xsl:value-of select="not(iqtig:valueJEDESIN($list1, $list2))"/>
	</xsl:function>	
	<xsl:function as="xs:boolean" name="iqtig:valueNICHTIN">
		<xsl:param name="list1"/>
		<xsl:param name="list2"/>
		<xsl:value-of select="iqtig:valueKEINSIN($list1, $list2)"/>
	</xsl:function>
	<xsl:function as="xs:boolean" name="iqtig:valueIN">
		<xsl:param name="list1"/>
		<xsl:param name="list2"/>
		<xsl:value-of select="not(iqtig:valueNICHTIN($list1, $list2))"/>
	</xsl:function>	
</xsl:stylesheet>
